searchData={"items":[{"type":"module","title":"StepFlow","doc":"StepFlow provide an entire system to manage workflows.\n\nIt provides different parts:\n- Connection with a database using Ecto to store Workflow status\n- a connection with a message broker to interact with workers\n- a RESTful API to create, list and interact with workflows","ref":"StepFlow.html"},{"type":"macro","title":"StepFlow.__using__/1","doc":"When used, dispatch to the appropriate controller/view/etc.","ref":"StepFlow.html#__using__/1"},{"type":"function","title":"StepFlow.controller/0","doc":"Helper to include tools in Controllers","ref":"StepFlow.html#controller/0"},{"type":"function","title":"StepFlow.router/0","doc":"Helper to include tools in Router","ref":"StepFlow.html#router/0"},{"type":"function","title":"StepFlow.view/0","doc":"Helper to include tools in Views","ref":"StepFlow.html#view/0"},{"type":"module","title":"StepFlow.Amqp.CommonConsumer","doc":"Definition of a Common Consumer of RabbitMQ queue.\n\nTo implement a consumer,\n\n```elixir\ndefmodule MyModule do\n  use StepFlow.Amqp.CommonConsumer, %{\n    queue: \"name_of_the_rabbit_mq_queue\",\n    exchange \"name_of_exchange\",\n    consumer: &MyModule.consume/4\n  }\n\n  def consume(channel, tag, redelivered, payload) do\n    ...\n    Basic.ack(channel, tag)\n  end\nend\n```","ref":"StepFlow.Amqp.CommonConsumer.html"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.create_queues/2","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#create_queues/2"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.get_channel_check_interval/0","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#get_channel_check_interval/0"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.init_amqp_connection/4","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#init_amqp_connection/4"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.max_retries_reached?/1","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#max_retries_reached?/1"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.rabbitmq_connect/5","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#rabbitmq_connect/5"},{"type":"function","title":"StepFlow.Amqp.CommonConsumer.rabbitmq_disconnect/1","doc":"","ref":"StepFlow.Amqp.CommonConsumer.html#rabbitmq_disconnect/1"},{"type":"module","title":"StepFlow.Amqp.CommonEmitter","doc":"A common emitter to send job orders to workers.","ref":"StepFlow.Amqp.CommonEmitter.html"},{"type":"function","title":"StepFlow.Amqp.CommonEmitter.publish/4","doc":"Publish a message.\n\nExample:\n\n```elixir\nStepFlow.Amqp.CommonEmitter.publish_json(\"my_rabbit_mq_queue\", \"{\\\"key\\\": \\\"value\\\"}\")\n```","ref":"StepFlow.Amqp.CommonEmitter.html#publish/4"},{"type":"function","title":"StepFlow.Amqp.CommonEmitter.publish_json/5","doc":"Publish a message using JSON serialization before send it.\n\nExample:\n\n```elixir\nStepFlow.Amqp.CommonEmitter.publish_json(\"my_rabbit_mq_queue\", 0, %{key: \"value\"})\n```","ref":"StepFlow.Amqp.CommonEmitter.html#publish_json/5"},{"type":"module","title":"StepFlow.Amqp.CompletedConsumer","doc":"Consumer of all job with completed status.","ref":"StepFlow.Amqp.CompletedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.CompletedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.CompletedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.CompletedConsumer.consume/4","doc":"Consume messages with completed topic, update Job status and continue the workflow.","ref":"StepFlow.Amqp.CompletedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.CompletedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.CompletedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.ErrorConsumer","doc":"Consumer of all job with error status.","ref":"StepFlow.Amqp.ErrorConsumer.html"},{"type":"function","title":"StepFlow.Amqp.ErrorConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.ErrorConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.ErrorConsumer.consume/4","doc":"Consume message with error topic, update Job and send a notification.","ref":"StepFlow.Amqp.ErrorConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.ErrorConsumer.consume_error_message/5","doc":"","ref":"StepFlow.Amqp.ErrorConsumer.html#consume_error_message/5"},{"type":"function","title":"StepFlow.Amqp.ErrorConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.ErrorConsumer.html#disconnect/0"},{"type":"function","title":"StepFlow.Amqp.ErrorConsumer.publish_parent_job_error/2","doc":"","ref":"StepFlow.Amqp.ErrorConsumer.html#publish_parent_job_error/2"},{"type":"module","title":"StepFlow.Amqp.Helpers","doc":"Helpers for AMQP.","ref":"StepFlow.Amqp.Helpers.html"},{"type":"function","title":"StepFlow.Amqp.Helpers.convert_to_integer/1","doc":"","ref":"StepFlow.Amqp.Helpers.html#convert_to_integer/1"},{"type":"function","title":"StepFlow.Amqp.Helpers.get_amqp_connection_options/0","doc":"","ref":"StepFlow.Amqp.Helpers.html#get_amqp_connection_options/0"},{"type":"function","title":"StepFlow.Amqp.Helpers.get_amqp_connection_url/0","doc":"Get AMQP URL from the configuration or environment variables.\n- `hostname` Setup the hostname of the RabbitMQ service\n- `username` Setup the username of the RabbitMQ service\n- `password` Setup the password of the RabbitMQ service\n- `port` Setup the port of the RabbitMQ service\n- `virtual_host` Setup the virtual host of the RabbitMQ service\n\nHardcoded example:\n\n    config :step_flow, StepFlow.Amqp,\n      hostname: \"example.com\",\n      port: \"5678\",\n      username: \"mediacloudai\",\n      password: \"mediacloudai\",\n      virtual_host: \"media_cloud_ai_dev\"\n\nEnvironment getter example:\n\n    config :step_flow, StepFlow.Amqp,\n      hostname: {:system, \"AMQP_HOSTNAME\"},\n      port: {:system, \"AMQP_PORT\"},\n      username: {:system, \"AMQP_USERNAME\"},\n      password: {:system, \"AMQP_PASSWORD\"},\n      virtual_host: {:system, \"AMQP_VIRTUAL_HOST\"},","ref":"StepFlow.Amqp.Helpers.html#get_amqp_connection_url/0"},{"type":"function","title":"StepFlow.Amqp.Helpers.get_amqp_delivery_mode/0","doc":"","ref":"StepFlow.Amqp.Helpers.html#get_amqp_delivery_mode/0"},{"type":"function","title":"StepFlow.Amqp.Helpers.get_amqp_message_options/1","doc":"","ref":"StepFlow.Amqp.Helpers.html#get_amqp_message_options/1"},{"type":"function","title":"StepFlow.Amqp.Helpers.get_amqp_server_configuration/0","doc":"","ref":"StepFlow.Amqp.Helpers.html#get_amqp_server_configuration/0"},{"type":"module","title":"StepFlow.Amqp.ProgressionConsumer","doc":"Consumer of all progression jobs.","ref":"StepFlow.Amqp.ProgressionConsumer.html"},{"type":"function","title":"StepFlow.Amqp.ProgressionConsumer.add_progression/4","doc":"","ref":"StepFlow.Amqp.ProgressionConsumer.html#add_progression/4"},{"type":"function","title":"StepFlow.Amqp.ProgressionConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.ProgressionConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.ProgressionConsumer.consume/4","doc":"Consume message with job progression and save it in database.","ref":"StepFlow.Amqp.ProgressionConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.ProgressionConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.ProgressionConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.StoppedConsumer","doc":"Consumer of all job with stopped status.","ref":"StepFlow.Amqp.StoppedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.StoppedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.StoppedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.StoppedConsumer.consume/4","doc":"Consume messages with stopped topic, update Job status and continue the workflow.","ref":"StepFlow.Amqp.StoppedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.StoppedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.StoppedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.Supervisor","doc":"Supervisor of Step Flow.\n\nIt manages AMQP connection to emit and consume messages as well as\nmanages the StepManager to drive workflows.","ref":"StepFlow.Amqp.Supervisor.html"},{"type":"function","title":"StepFlow.Amqp.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.Supervisor.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.Supervisor.start_children/0","doc":"","ref":"StepFlow.Amqp.Supervisor.html#start_children/0"},{"type":"function","title":"StepFlow.Amqp.Supervisor.stop_children/0","doc":"","ref":"StepFlow.Amqp.Supervisor.html#stop_children/0"},{"type":"module","title":"StepFlow.Amqp.WorkerCreatedConsumer","doc":"Consumer of all worker creations.","ref":"StepFlow.Amqp.WorkerCreatedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerCreatedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerCreatedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerCreatedConsumer.consume/4","doc":"Consume worker created message.","ref":"StepFlow.Amqp.WorkerCreatedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerCreatedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerCreatedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.WorkerDiscoveryConsumer","doc":"Consumer of Worker Descriptions.","ref":"StepFlow.Amqp.WorkerDiscoveryConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerDiscoveryConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerDiscoveryConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerDiscoveryConsumer.consume/4","doc":"Consume messages, create Worker Definition if it's not already declared.","ref":"StepFlow.Amqp.WorkerDiscoveryConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerDiscoveryConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerDiscoveryConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.WorkerInitializedConsumer","doc":"Consumer of all worker inits.","ref":"StepFlow.Amqp.WorkerInitializedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerInitializedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerInitializedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerInitializedConsumer.consume/4","doc":"Consume worker initialized message.","ref":"StepFlow.Amqp.WorkerInitializedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerInitializedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerInitializedConsumer.html#disconnect/0"},{"type":"function","title":"StepFlow.Amqp.WorkerInitializedConsumer.handle_initialized_message_for_job/3","doc":"","ref":"StepFlow.Amqp.WorkerInitializedConsumer.html#handle_initialized_message_for_job/3"},{"type":"module","title":"StepFlow.Amqp.WorkerStartedConsumer","doc":"Consumer of all worker starts.","ref":"StepFlow.Amqp.WorkerStartedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerStartedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerStartedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerStartedConsumer.consume/4","doc":"Consume worker started message.","ref":"StepFlow.Amqp.WorkerStartedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerStartedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerStartedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.WorkerStatusConsumer","doc":"Consumer of all worker statuses.","ref":"StepFlow.Amqp.WorkerStatusConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerStatusConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerStatusConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerStatusConsumer.consume/4","doc":"Consume worker status message.","ref":"StepFlow.Amqp.WorkerStatusConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerStatusConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerStatusConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.WorkerTerminatedConsumer","doc":"Consumer of all worker terminations.","ref":"StepFlow.Amqp.WorkerTerminatedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerTerminatedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerTerminatedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerTerminatedConsumer.consume/4","doc":"Consume worker terminated message.","ref":"StepFlow.Amqp.WorkerTerminatedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerTerminatedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerTerminatedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.Amqp.WorkerUpdatedConsumer","doc":"Consumer of all worker updates.","ref":"StepFlow.Amqp.WorkerUpdatedConsumer.html"},{"type":"function","title":"StepFlow.Amqp.WorkerUpdatedConsumer.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Amqp.WorkerUpdatedConsumer.html#child_spec/1"},{"type":"function","title":"StepFlow.Amqp.WorkerUpdatedConsumer.consume/4","doc":"Consume worker updated message.","ref":"StepFlow.Amqp.WorkerUpdatedConsumer.html#consume/4"},{"type":"function","title":"StepFlow.Amqp.WorkerUpdatedConsumer.disconnect/0","doc":"","ref":"StepFlow.Amqp.WorkerUpdatedConsumer.html#disconnect/0"},{"type":"module","title":"StepFlow.ArtifactView","doc":"","ref":"StepFlow.ArtifactView.html"},{"type":"function","title":"StepFlow.ArtifactView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.ArtifactView.html#__resource__/0"},{"type":"function","title":"StepFlow.ArtifactView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.ArtifactView.html#render/2"},{"type":"function","title":"StepFlow.ArtifactView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.ArtifactView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Artifacts","doc":"The Artifacts context.","ref":"StepFlow.Artifacts.html"},{"type":"function","title":"StepFlow.Artifacts.create_artifact/1","doc":"Creates an artifact.","ref":"StepFlow.Artifacts.html#create_artifact/1"},{"type":"function","title":"Examples - StepFlow.Artifacts.create_artifact/1","doc":"iex> create_artifact(%{field: value})\n    {:ok, %Artifact{}}\n\n    iex> create_artifact(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Artifacts.html#create_artifact/1-examples"},{"type":"module","title":"StepFlow.Authorization","doc":"StepFlow provide an entire system to manage workflows.\n\nIt provides differents parts:\n- Connection with a database using Ecto to store Workflow status\n- a connection with a message broker to interact with workers\n- a RESTful API to create, list and interact with workflows","ref":"StepFlow.Authorization.html"},{"type":"function","title":"StepFlow.Authorization.call/2","doc":"","ref":"StepFlow.Authorization.html#call/2"},{"type":"function","title":"StepFlow.Authorization.check/1","doc":"Check authorization for the connection using the method and the path.\n\nIt can be configured using:\n\n```elixir\n  config :step_flow,\n    authorize: [\n      module: ExBackendWeb.Authorize,\n      get_jobs: [:user_check, :specific_right_check]\n    ]\n```","ref":"StepFlow.Authorization.html#check/1"},{"type":"function","title":"StepFlow.Authorization.check_metrics_enabled/1","doc":"","ref":"StepFlow.Authorization.html#check_metrics_enabled/1"},{"type":"function","title":"StepFlow.Authorization.init/1","doc":"","ref":"StepFlow.Authorization.html#init/1"},{"type":"module","title":"StepFlow.BlackListView","doc":"","ref":"StepFlow.BlackListView.html"},{"type":"function","title":"StepFlow.BlackListView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.BlackListView.html#__resource__/0"},{"type":"function","title":"StepFlow.BlackListView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.BlackListView.html#render/2"},{"type":"function","title":"StepFlow.BlackListView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.BlackListView.html#template_not_found/2"},{"type":"module","title":"StepFlow.ChangesetView","doc":"","ref":"StepFlow.ChangesetView.html"},{"type":"function","title":"StepFlow.ChangesetView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.ChangesetView.html#__resource__/0"},{"type":"function","title":"StepFlow.ChangesetView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.ChangesetView.html#render/2"},{"type":"function","title":"StepFlow.ChangesetView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.ChangesetView.html#template_not_found/2"},{"type":"function","title":"StepFlow.ChangesetView.translate_errors/1","doc":"Traverses and translates changeset errors.\n\nSee `Ecto.Changeset.traverse_errors/2` for more details.","ref":"StepFlow.ChangesetView.html#translate_errors/1"},{"type":"module","title":"StepFlow.Controllers.Statistics.Durations","doc":"The duration statistics accessor.","ref":"StepFlow.Controllers.Statistics.Durations.html"},{"type":"function","title":"StepFlow.Controllers.Statistics.Durations.get_jobs_duration_statistics/1","doc":"","ref":"StepFlow.Controllers.Statistics.Durations.html#get_jobs_duration_statistics/1"},{"type":"function","title":"StepFlow.Controllers.Statistics.Durations.get_workflows_duration_statistics/1","doc":"","ref":"StepFlow.Controllers.Statistics.Durations.html#get_workflows_duration_statistics/1"},{"type":"function","title":"StepFlow.Controllers.Statistics.Durations.list_durations_for_jobs/1","doc":"","ref":"StepFlow.Controllers.Statistics.Durations.html#list_durations_for_jobs/1"},{"type":"function","title":"StepFlow.Controllers.Statistics.Durations.list_durations_for_workflows/1","doc":"","ref":"StepFlow.Controllers.Statistics.Durations.html#list_durations_for_workflows/1"},{"type":"module","title":"StepFlow.DurationStatisticsView","doc":"","ref":"StepFlow.DurationStatisticsView.html"},{"type":"function","title":"StepFlow.DurationStatisticsView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.DurationStatisticsView.html#__resource__/0"},{"type":"function","title":"StepFlow.DurationStatisticsView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.DurationStatisticsView.html#render/2"},{"type":"function","title":"StepFlow.DurationStatisticsView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.DurationStatisticsView.html#template_not_found/2"},{"type":"module","title":"StepFlow.DurationsView","doc":"","ref":"StepFlow.DurationsView.html"},{"type":"function","title":"StepFlow.DurationsView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.DurationsView.html#__resource__/0"},{"type":"function","title":"StepFlow.DurationsView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.DurationsView.html#render/2"},{"type":"function","title":"StepFlow.DurationsView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.DurationsView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Endpoint","doc":"","ref":"StepFlow.Endpoint.html"},{"type":"function","title":"StepFlow.Endpoint.broadcast/3","doc":"","ref":"StepFlow.Endpoint.html#broadcast/3"},{"type":"function","title":"StepFlow.Endpoint.broadcast!/3","doc":"","ref":"StepFlow.Endpoint.html#broadcast!/3"},{"type":"function","title":"StepFlow.Endpoint.broadcast_from/4","doc":"","ref":"StepFlow.Endpoint.html#broadcast_from/4"},{"type":"function","title":"StepFlow.Endpoint.broadcast_from!/4","doc":"","ref":"StepFlow.Endpoint.html#broadcast_from!/4"},{"type":"function","title":"StepFlow.Endpoint.call/2","doc":"","ref":"StepFlow.Endpoint.html#call/2"},{"type":"function","title":"StepFlow.Endpoint.child_spec/1","doc":"Returns the child specification to start the endpoint\nunder a supervision tree.","ref":"StepFlow.Endpoint.html#child_spec/1"},{"type":"function","title":"StepFlow.Endpoint.config/2","doc":"Returns the endpoint configuration for `key`\n\nReturns `default` if the key does not exist.","ref":"StepFlow.Endpoint.html#config/2"},{"type":"function","title":"StepFlow.Endpoint.config_change/2","doc":"Reloads the configuration given the application environment changes.","ref":"StepFlow.Endpoint.html#config_change/2"},{"type":"function","title":"StepFlow.Endpoint.host/0","doc":"Returns the host for the given endpoint.","ref":"StepFlow.Endpoint.html#host/0"},{"type":"function","title":"StepFlow.Endpoint.init/1","doc":"","ref":"StepFlow.Endpoint.html#init/1"},{"type":"function","title":"StepFlow.Endpoint.init/2","doc":"Callback invoked for dynamically configuring the endpoint.\n\nIt receives the endpoint configuration and checks if\nconfiguration should be loaded from the system environment.","ref":"StepFlow.Endpoint.html#init/2"},{"type":"function","title":"StepFlow.Endpoint.local_broadcast/3","doc":"","ref":"StepFlow.Endpoint.html#local_broadcast/3"},{"type":"function","title":"StepFlow.Endpoint.local_broadcast_from/4","doc":"","ref":"StepFlow.Endpoint.html#local_broadcast_from/4"},{"type":"function","title":"StepFlow.Endpoint.path/1","doc":"Generates the path information when routing to this endpoint.","ref":"StepFlow.Endpoint.html#path/1"},{"type":"function","title":"StepFlow.Endpoint.script_name/0","doc":"Generates the script name.","ref":"StepFlow.Endpoint.html#script_name/0"},{"type":"function","title":"StepFlow.Endpoint.server_info/1","doc":"Returns the address and port that the server is running on","ref":"StepFlow.Endpoint.html#server_info/1"},{"type":"function","title":"StepFlow.Endpoint.start_link/1","doc":"Starts the endpoint supervision tree.\n\nAll other options are merged into the endpoint configuration.","ref":"StepFlow.Endpoint.html#start_link/1"},{"type":"function","title":"StepFlow.Endpoint.static_integrity/1","doc":"Generates a base64-encoded cryptographic hash (sha512) to a static file\nin `priv/static`. Meant to be used for Subresource Integrity with CDNs.","ref":"StepFlow.Endpoint.html#static_integrity/1"},{"type":"function","title":"StepFlow.Endpoint.static_lookup/1","doc":"Returns a two item tuple with the first item being the `static_path`\nand the second item being the `static_integrity`.","ref":"StepFlow.Endpoint.html#static_lookup/1"},{"type":"function","title":"StepFlow.Endpoint.static_path/1","doc":"Generates a route to a static file in `priv/static`.","ref":"StepFlow.Endpoint.html#static_path/1"},{"type":"function","title":"StepFlow.Endpoint.static_url/0","doc":"Generates the static URL without any path information.\n\nIt uses the configuration under `:static_url` to generate\nsuch. It falls back to `:url` if `:static_url` is not set.","ref":"StepFlow.Endpoint.html#static_url/0"},{"type":"function","title":"StepFlow.Endpoint.struct_url/0","doc":"Generates the endpoint base URL but as a `URI` struct.\n\nIt uses the configuration under `:url` to generate such.\nUseful for manipulating the URL data and passing it to\nURL helpers.","ref":"StepFlow.Endpoint.html#struct_url/0"},{"type":"function","title":"StepFlow.Endpoint.subscribe/2","doc":"","ref":"StepFlow.Endpoint.html#subscribe/2"},{"type":"function","title":"StepFlow.Endpoint.unsubscribe/1","doc":"","ref":"StepFlow.Endpoint.html#unsubscribe/1"},{"type":"function","title":"StepFlow.Endpoint.url/0","doc":"Generates the endpoint base URL without any path information.\n\nIt uses the configuration under `:url` to generate such.","ref":"StepFlow.Endpoint.html#url/0"},{"type":"module","title":"StepFlow.ErrorHelpers","doc":"Conveniences for translating and building error messages.","ref":"StepFlow.ErrorHelpers.html"},{"type":"function","title":"StepFlow.ErrorHelpers.error_tag/2","doc":"Generates tag for inlined form input errors.","ref":"StepFlow.ErrorHelpers.html#error_tag/2"},{"type":"function","title":"StepFlow.ErrorHelpers.translate_error/1","doc":"Translates an error message using gettext.","ref":"StepFlow.ErrorHelpers.html#translate_error/1"},{"type":"module","title":"StepFlow.ErrorView","doc":"","ref":"StepFlow.ErrorView.html"},{"type":"function","title":"StepFlow.ErrorView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.ErrorView.html#__resource__/0"},{"type":"function","title":"StepFlow.ErrorView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.ErrorView.html#render/2"},{"type":"function","title":"StepFlow.ErrorView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.ErrorView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Gettext","doc":"A module providing Internationalization with a gettext-based API.\n\nBy using [Gettext](https://hexdocs.pm/gettext),\nyour module gains a set of macros for translations, for example:\n\n    import StepFlow.Gettext\n\n    # Simple translation\n    gettext \"Here is the string to translate\"\n\n    # Plural translation\n    ngettext \"Here is the string to translate\",\n             \"Here are the strings to translate\",\n             3\n\n    # Domain-based translation\n    dgettext \"errors\", \"Here is the error message to translate\"\n\nSee the [Gettext Docs](https://hexdocs.pm/gettext) for detailed usage.","ref":"StepFlow.Gettext.html"},{"type":"macro","title":"StepFlow.Gettext.dgettext/3","doc":"","ref":"StepFlow.Gettext.html#dgettext/3"},{"type":"macro","title":"StepFlow.Gettext.dgettext_noop/2","doc":"","ref":"StepFlow.Gettext.html#dgettext_noop/2"},{"type":"macro","title":"StepFlow.Gettext.dngettext/5","doc":"","ref":"StepFlow.Gettext.html#dngettext/5"},{"type":"macro","title":"StepFlow.Gettext.dngettext_noop/3","doc":"","ref":"StepFlow.Gettext.html#dngettext_noop/3"},{"type":"macro","title":"StepFlow.Gettext.dpgettext/4","doc":"","ref":"StepFlow.Gettext.html#dpgettext/4"},{"type":"macro","title":"StepFlow.Gettext.dpgettext_noop/3","doc":"","ref":"StepFlow.Gettext.html#dpgettext_noop/3"},{"type":"macro","title":"StepFlow.Gettext.dpngettext/6","doc":"","ref":"StepFlow.Gettext.html#dpngettext/6"},{"type":"macro","title":"StepFlow.Gettext.dpngettext_noop/4","doc":"","ref":"StepFlow.Gettext.html#dpngettext_noop/4"},{"type":"macro","title":"StepFlow.Gettext.gettext/2","doc":"","ref":"StepFlow.Gettext.html#gettext/2"},{"type":"macro","title":"StepFlow.Gettext.gettext_comment/1","doc":"","ref":"StepFlow.Gettext.html#gettext_comment/1"},{"type":"macro","title":"StepFlow.Gettext.gettext_noop/1","doc":"","ref":"StepFlow.Gettext.html#gettext_noop/1"},{"type":"function","title":"StepFlow.Gettext.handle_missing_bindings/2","doc":"","ref":"StepFlow.Gettext.html#handle_missing_bindings/2"},{"type":"function","title":"StepFlow.Gettext.handle_missing_plural_translation/7","doc":"","ref":"StepFlow.Gettext.html#handle_missing_plural_translation/7"},{"type":"function","title":"StepFlow.Gettext.handle_missing_translation/5","doc":"","ref":"StepFlow.Gettext.html#handle_missing_translation/5"},{"type":"function","title":"StepFlow.Gettext.lgettext/5","doc":"","ref":"StepFlow.Gettext.html#lgettext/5"},{"type":"function","title":"StepFlow.Gettext.lngettext/7","doc":"","ref":"StepFlow.Gettext.html#lngettext/7"},{"type":"macro","title":"StepFlow.Gettext.ngettext/4","doc":"","ref":"StepFlow.Gettext.html#ngettext/4"},{"type":"macro","title":"StepFlow.Gettext.ngettext_noop/2","doc":"","ref":"StepFlow.Gettext.html#ngettext_noop/2"},{"type":"macro","title":"StepFlow.Gettext.pgettext/3","doc":"","ref":"StepFlow.Gettext.html#pgettext/3"},{"type":"macro","title":"StepFlow.Gettext.pgettext_noop/2","doc":"","ref":"StepFlow.Gettext.html#pgettext_noop/2"},{"type":"macro","title":"StepFlow.Gettext.pngettext/5","doc":"","ref":"StepFlow.Gettext.html#pngettext/5"},{"type":"macro","title":"StepFlow.Gettext.pngettext_noop/3","doc":"","ref":"StepFlow.Gettext.html#pngettext_noop/3"},{"type":"module","title":"StepFlow.JobView","doc":"","ref":"StepFlow.JobView.html"},{"type":"function","title":"StepFlow.JobView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.JobView.html#__resource__/0"},{"type":"function","title":"StepFlow.JobView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.JobView.html#render/2"},{"type":"function","title":"StepFlow.JobView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.JobView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Jobs","doc":"The Jobs context.","ref":"StepFlow.Jobs.html"},{"type":"function","title":"StepFlow.Jobs.abort_jobs/3","doc":"","ref":"StepFlow.Jobs.html#abort_jobs/3"},{"type":"function","title":"StepFlow.Jobs.apply_default_query_filters/2","doc":"","ref":"StepFlow.Jobs.html#apply_default_query_filters/2"},{"type":"function","title":"StepFlow.Jobs.apply_rights/2","doc":"","ref":"StepFlow.Jobs.html#apply_rights/2"},{"type":"function","title":"StepFlow.Jobs.change_job/1","doc":"Returns an `%Ecto.Changeset{}` for tracking job changes.","ref":"StepFlow.Jobs.html#change_job/1"},{"type":"function","title":"Examples - StepFlow.Jobs.change_job/1","doc":"iex> change_job(job)\n    %Ecto.Changeset{source: %Job{}}","ref":"StepFlow.Jobs.html#change_job/1-examples"},{"type":"function","title":"StepFlow.Jobs.copy_job/1","doc":"","ref":"StepFlow.Jobs.html#copy_job/1"},{"type":"function","title":"StepFlow.Jobs.create_completed_job/3","doc":"Creates a job with a completed status.","ref":"StepFlow.Jobs.html#create_completed_job/3"},{"type":"function","title":"Examples - StepFlow.Jobs.create_completed_job/3","doc":"iex> create_completed_job(workflow, step_id, \"webhook_notification\")\n    {:ok, \"completed\"}","ref":"StepFlow.Jobs.html#create_completed_job/3-examples"},{"type":"function","title":"StepFlow.Jobs.create_error_job/4","doc":"Creates a job with an error status.","ref":"StepFlow.Jobs.html#create_error_job/4"},{"type":"function","title":"Examples - StepFlow.Jobs.create_error_job/4","doc":"iex> create_error_job(workflow, step_id, \"download_http\", \"unsupported step\")\n    {:ok, \"created\"}","ref":"StepFlow.Jobs.html#create_error_job/4-examples"},{"type":"function","title":"StepFlow.Jobs.create_job/1","doc":"Creates a job.","ref":"StepFlow.Jobs.html#create_job/1"},{"type":"function","title":"Examples - StepFlow.Jobs.create_job/1","doc":"iex> create_job(%{field: value})\n    {:ok, %Job{}}\n\n    iex> create_job(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Jobs.html#create_job/1-examples"},{"type":"function","title":"StepFlow.Jobs.create_paused_job/4","doc":"Creates a job with a paused status.","ref":"StepFlow.Jobs.html#create_paused_job/4"},{"type":"function","title":"Examples - StepFlow.Jobs.create_paused_job/4","doc":"iex> create_paused_job(workflow, 1, \"download_http\")\n    {:ok, \"paused\"}","ref":"StepFlow.Jobs.html#create_paused_job/4-examples"},{"type":"function","title":"StepFlow.Jobs.create_skipped_job/3","doc":"Creates a job with a skipped status.","ref":"StepFlow.Jobs.html#create_skipped_job/3"},{"type":"function","title":"Examples - StepFlow.Jobs.create_skipped_job/3","doc":"iex> create_skipped_job(workflow, 1, \"download_http\")\n    {:ok, \"skipped\"}","ref":"StepFlow.Jobs.html#create_skipped_job/3-examples"},{"type":"function","title":"StepFlow.Jobs.delete_job/1","doc":"Deletes a Job.","ref":"StepFlow.Jobs.html#delete_job/1"},{"type":"function","title":"Examples - StepFlow.Jobs.delete_job/1","doc":"iex> delete_job(job)\n    {:ok, %Job{}}\n\n    iex> delete_job(job)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Jobs.html#delete_job/1-examples"},{"type":"function","title":"StepFlow.Jobs.filter_status/2","doc":"","ref":"StepFlow.Jobs.html#filter_status/2"},{"type":"function","title":"StepFlow.Jobs.filter_worker_instance_id/2","doc":"","ref":"StepFlow.Jobs.html#filter_worker_instance_id/2"},{"type":"function","title":"StepFlow.Jobs.filter_worker_label/2","doc":"","ref":"StepFlow.Jobs.html#filter_worker_label/2"},{"type":"function","title":"StepFlow.Jobs.filter_worker_version/2","doc":"","ref":"StepFlow.Jobs.html#filter_worker_version/2"},{"type":"function","title":"StepFlow.Jobs.get_by/1","doc":"Gets a single job by workflow ID and step ID","ref":"StepFlow.Jobs.html#get_by/1"},{"type":"function","title":"Examples - StepFlow.Jobs.get_by/1","doc":"iex> get_job(123)\n    %Job{}\n\n    iex> get_job(456)\n    nil","ref":"StepFlow.Jobs.html#get_by/1-examples"},{"type":"function","title":"StepFlow.Jobs.get_by!/1","doc":"Gets a single job by workflow ID and step ID","ref":"StepFlow.Jobs.html#get_by!/1"},{"type":"function","title":"Examples - StepFlow.Jobs.get_by!/1","doc":"iex> get_job(123)\n    %Job{}\n\n    iex> get_job(456)\n    nil","ref":"StepFlow.Jobs.html#get_by!/1-examples"},{"type":"function","title":"StepFlow.Jobs.get_job/1","doc":"Gets a single job.","ref":"StepFlow.Jobs.html#get_job/1"},{"type":"function","title":"Examples - StepFlow.Jobs.get_job/1","doc":"iex> get_job(123)\n    %Job{}\n\n    iex> get_job(456)\n    nil","ref":"StepFlow.Jobs.html#get_job/1-examples"},{"type":"function","title":"StepFlow.Jobs.get_job!/1","doc":"Gets a single job.\n\nRaises `Ecto.NoResultsError` if the Job does not exist.","ref":"StepFlow.Jobs.html#get_job!/1"},{"type":"function","title":"Examples - StepFlow.Jobs.get_job!/1","doc":"iex> get_job!(123)\n    %Job{}\n\n    iex> get_job!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Jobs.html#get_job!/1-examples"},{"type":"function","title":"StepFlow.Jobs.get_job_with_status!/1","doc":"Gets a single job with its related status.\n\nRaises `Ecto.NoResultsError` if the Job does not exist.","ref":"StepFlow.Jobs.html#get_job_with_status!/1"},{"type":"function","title":"Examples - StepFlow.Jobs.get_job_with_status!/1","doc":"iex> get_job_with_status!(123)\n    %Job{}\n\n    iex> get_job!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Jobs.html#get_job_with_status!/1-examples"},{"type":"function","title":"StepFlow.Jobs.get_pending_jobs_by_type/0","doc":"Returns the list of jobs pending\"","ref":"StepFlow.Jobs.html#get_pending_jobs_by_type/0"},{"type":"function","title":"StepFlow.Jobs.get_processing_jobs_by_type/0","doc":"Returns the list of jobs pending\"","ref":"StepFlow.Jobs.html#get_processing_jobs_by_type/0"},{"type":"function","title":"StepFlow.Jobs.internal_list_jobs/1","doc":"","ref":"StepFlow.Jobs.html#internal_list_jobs/1"},{"type":"function","title":"StepFlow.Jobs.list_jobs/1","doc":"Returns the list of jobs.","ref":"StepFlow.Jobs.html#list_jobs/1"},{"type":"function","title":"Examples - StepFlow.Jobs.list_jobs/1","doc":"iex> list_jobs()\n    [%Job{}, ...]","ref":"StepFlow.Jobs.html#list_jobs/1-examples"},{"type":"function","title":"StepFlow.Jobs.skip_jobs/3","doc":"Set skipped status to all queued jobs.","ref":"StepFlow.Jobs.html#skip_jobs/3"},{"type":"function","title":"Examples - StepFlow.Jobs.skip_jobs/3","doc":"iex> skip_jobs(workflow, step_id, \"download_http\")\n    :ok","ref":"StepFlow.Jobs.html#skip_jobs/3-examples"},{"type":"function","title":"StepFlow.Jobs.update_job/2","doc":"Updates a job.","ref":"StepFlow.Jobs.html#update_job/2"},{"type":"function","title":"Examples - StepFlow.Jobs.update_job/2","doc":"iex> update_job(job, %{field: new_value})\n    {:ok, %Job{}}\n\n    iex> update_job(job, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Jobs.html#update_job/2-examples"},{"type":"module","title":"StepFlow.Jobs.Status.StateEnum","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.cast/1","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#cast/1"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.dump/1","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#dump/1"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.embed_as/1","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#embed_as/1"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.equal?/2","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#equal?/2"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.load/1","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#load/1"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.type/0","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#type/0"},{"type":"function","title":"StepFlow.Jobs.Status.StateEnum.valid_value?/1","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#valid_value?/1"},{"type":"type","title":"StepFlow.Jobs.Status.StateEnum.t/0","doc":"","ref":"StepFlow.Jobs.Status.StateEnum.html#t:t/0"},{"type":"module","title":"StepFlow.LiveWorkers","doc":"The LiveWorkers context.","ref":"StepFlow.LiveWorkers.html"},{"type":"function","title":"StepFlow.LiveWorkers.change_live_worker/1","doc":"Returns an `%Ecto.Changeset{}` for tracking live worker changes.","ref":"StepFlow.LiveWorkers.html#change_live_worker/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.change_live_worker/1","doc":"iex> change_live_worker(job)\n    %Ecto.Changeset{source: %LiveWorker{}}","ref":"StepFlow.LiveWorkers.html#change_live_worker/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.create_live_worker/1","doc":"Creates a Live Worker entry.","ref":"StepFlow.LiveWorkers.html#create_live_worker/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.create_live_worker/1","doc":"iex> create_live_worker(%{field: value})\n    {:ok, %LiveWorker{}}\n\n    iex> create_live_worker(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.LiveWorkers.html#create_live_worker/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.delete_live_worker/1","doc":"Deletes a LiveWorker.","ref":"StepFlow.LiveWorkers.html#delete_live_worker/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.delete_live_worker/1","doc":"iex> delete_live_worker(live_worker)\n    {:ok, %LiveWorker{}}\n\n    iex> delete_live_worker(live_worker)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.LiveWorkers.html#delete_live_worker/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.get_by/1","doc":"Gets a single live worker by job ID","ref":"StepFlow.LiveWorkers.html#get_by/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.get_by/1","doc":"iex> get_by(%{\"job_id\" => 123})\n    %LiveWorker{}\n\n    iex> get_by(%{\"job_id\" => 456})\n    nil","ref":"StepFlow.LiveWorkers.html#get_by/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.get_by!/1","doc":"Gets a single live worker by job ID","ref":"StepFlow.LiveWorkers.html#get_by!/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.get_by!/1","doc":"iex> get_by!(123)\n    %LiveWorker{}\n\n    iex> get_by!(456)\n    nil","ref":"StepFlow.LiveWorkers.html#get_by!/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.list_live_workers/1","doc":"Returns the list of Live Worker.","ref":"StepFlow.LiveWorkers.html#list_live_workers/1"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.list_live_workers/1","doc":"iex> StepFlow.LiveWorkers.list_live_workers()\n    %{data: [], page: 0, size: 10, total: 0}","ref":"StepFlow.LiveWorkers.html#list_live_workers/1-examples"},{"type":"function","title":"StepFlow.LiveWorkers.update_live_worker/2","doc":"Updates a live worker.","ref":"StepFlow.LiveWorkers.html#update_live_worker/2"},{"type":"function","title":"Examples - StepFlow.LiveWorkers.update_live_worker/2","doc":"iex> update_live_worker(job, %{field: new_value})\n    {:ok, %LiveWorker{}}\n\n    iex> update_live_worker(job, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.LiveWorkers.html#update_live_worker/2-examples"},{"type":"module","title":"StepFlow.LiveWorkersView","doc":"","ref":"StepFlow.LiveWorkersView.html"},{"type":"function","title":"StepFlow.LiveWorkersView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.LiveWorkersView.html#__resource__/0"},{"type":"function","title":"StepFlow.LiveWorkersView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.LiveWorkersView.html#render/2"},{"type":"function","title":"StepFlow.LiveWorkersView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.LiveWorkersView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Map","doc":"Extend Map with some additional functions.","ref":"StepFlow.Map.html"},{"type":"function","title":"StepFlow.Map.get_by_key_or_atom/3","doc":"Get a key matching on an atom or a string.\n\nDefault value can be specified.","ref":"StepFlow.Map.html#get_by_key_or_atom/3"},{"type":"function","title":"Examples - StepFlow.Map.get_by_key_or_atom/3","doc":"iex> StepFlow.Map.get_by_key_or_atom(%{key: \"value\"}, :key)\n    \"value\"\n\n    iex> StepFlow.Map.get_by_key_or_atom(%{\"key\" => \"value\"}, :key)\n    \"value\"\n\n    iex> StepFlow.Map.get_by_key_or_atom(%{key: \"value\"}, \"key\")\n    \"value\"\n\n    iex> StepFlow.Map.get_by_key_or_atom(%{\"key\" => \"value\"}, \"key\")\n    \"value\"","ref":"StepFlow.Map.html#get_by_key_or_atom/3-examples"},{"type":"function","title":"StepFlow.Map.keys_to_atoms/1","doc":"","ref":"StepFlow.Map.html#keys_to_atoms/1"},{"type":"function","title":"StepFlow.Map.pair_to_atoms/2","doc":"","ref":"StepFlow.Map.html#pair_to_atoms/2"},{"type":"function","title":"StepFlow.Map.replace_by_atom/3","doc":"Replace an item in a map, with atom or string keys.","ref":"StepFlow.Map.html#replace_by_atom/3"},{"type":"function","title":"Examples - StepFlow.Map.replace_by_atom/3","doc":"iex> StepFlow.Map.replace_by_atom(%{key: \"value\"}, :key, \"replaced_value\")\n    %{key: \"replaced_value\"}\n\n    iex> StepFlow.Map.replace_by_atom(%{\"key\" => \"value\"}, :key, \"replaced_value\")\n    %{key: \"replaced_value\"}\n\n    iex> StepFlow.Map.replace_by_atom(%{\"key\" => \"value\"}, \"key\", \"replaced_value\")\n    %{key: \"replaced_value\"}","ref":"StepFlow.Map.html#replace_by_atom/3-examples"},{"type":"function","title":"StepFlow.Map.replace_by_string/3","doc":"","ref":"StepFlow.Map.html#replace_by_string/3"},{"type":"module","title":"StepFlow.Metrics.JobInstrumenter","doc":"Prometheus metrics instrumenter to call jobs metric collectors","ref":"StepFlow.Metrics.JobInstrumenter.html"},{"type":"function","title":"StepFlow.Metrics.JobInstrumenter.inc/3","doc":"","ref":"StepFlow.Metrics.JobInstrumenter.html#inc/3"},{"type":"function","title":"StepFlow.Metrics.JobInstrumenter.setup/0","doc":"","ref":"StepFlow.Metrics.JobInstrumenter.html#setup/0"},{"type":"module","title":"StepFlow.Metrics.JobsPendingCollector","doc":"Prometheus metrics collector for pending jobs","ref":"StepFlow.Metrics.JobsPendingCollector.html"},{"type":"function","title":"StepFlow.Metrics.JobsPendingCollector.collect_metrics/2","doc":"","ref":"StepFlow.Metrics.JobsPendingCollector.html#collect_metrics/2"},{"type":"function","title":"StepFlow.Metrics.JobsPendingCollector.collect_mf/2","doc":"","ref":"StepFlow.Metrics.JobsPendingCollector.html#collect_mf/2"},{"type":"function","title":"StepFlow.Metrics.JobsPendingCollector.deregister_cleanup/1","doc":"","ref":"StepFlow.Metrics.JobsPendingCollector.html#deregister_cleanup/1"},{"type":"module","title":"StepFlow.Metrics.LiveWorkflowProcessingCollector","doc":"Prometheus metrics collector for live workflows processing","ref":"StepFlow.Metrics.LiveWorkflowProcessingCollector.html"},{"type":"function","title":"StepFlow.Metrics.LiveWorkflowProcessingCollector.collect_metrics/2","doc":"","ref":"StepFlow.Metrics.LiveWorkflowProcessingCollector.html#collect_metrics/2"},{"type":"function","title":"StepFlow.Metrics.LiveWorkflowProcessingCollector.collect_mf/2","doc":"","ref":"StepFlow.Metrics.LiveWorkflowProcessingCollector.html#collect_mf/2"},{"type":"function","title":"StepFlow.Metrics.LiveWorkflowProcessingCollector.deregister_cleanup/1","doc":"","ref":"StepFlow.Metrics.LiveWorkflowProcessingCollector.html#deregister_cleanup/1"},{"type":"module","title":"StepFlow.Metrics.WorkflowCollector","doc":"Prometheus metrics collector for workflow duration","ref":"StepFlow.Metrics.WorkflowCollector.html"},{"type":"function","title":"StepFlow.Metrics.WorkflowCollector.collect_metrics/2","doc":"","ref":"StepFlow.Metrics.WorkflowCollector.html#collect_metrics/2"},{"type":"function","title":"StepFlow.Metrics.WorkflowCollector.collect_mf/2","doc":"","ref":"StepFlow.Metrics.WorkflowCollector.html#collect_mf/2"},{"type":"function","title":"StepFlow.Metrics.WorkflowCollector.deregister_cleanup/1","doc":"","ref":"StepFlow.Metrics.WorkflowCollector.html#deregister_cleanup/1"},{"type":"module","title":"StepFlow.Metrics.WorkflowInstrumenter","doc":"Prometheus metrics instrumenter to call workflow metric collectors","ref":"StepFlow.Metrics.WorkflowInstrumenter.html"},{"type":"function","title":"StepFlow.Metrics.WorkflowInstrumenter.inc/3","doc":"","ref":"StepFlow.Metrics.WorkflowInstrumenter.html#inc/3"},{"type":"function","title":"StepFlow.Metrics.WorkflowInstrumenter.setup/0","doc":"","ref":"StepFlow.Metrics.WorkflowInstrumenter.html#setup/0"},{"type":"module","title":"StepFlow.Notification","doc":"Send notifications to endpoint to be forwarded to websockets.","ref":"StepFlow.Notification.html"},{"type":"function","title":"StepFlow.Notification.send/2","doc":"","ref":"StepFlow.Notification.html#send/2"},{"type":"module","title":"StepFlow.NotificationEndpointView","doc":"","ref":"StepFlow.NotificationEndpointView.html"},{"type":"function","title":"StepFlow.NotificationEndpointView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.NotificationEndpointView.html#__resource__/0"},{"type":"function","title":"StepFlow.NotificationEndpointView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.NotificationEndpointView.html#render/2"},{"type":"function","title":"StepFlow.NotificationEndpointView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.NotificationEndpointView.html#template_not_found/2"},{"type":"module","title":"StepFlow.NotificationHooks.NotificationEndpoints","doc":"The Notification endpoints context.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.change_notification_endpoint/1","doc":"Returns an `%Ecto.Changeset{}` for tracking notification_endpoint changes.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#change_notification_endpoint/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.change_notification_endpoint/1","doc":"iex> change_notification_endpoint(notification_endpoint)\n    %Ecto.Changeset{source: %NotificationEndpoint{}}","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#change_notification_endpoint/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.create_notification_endpoint/1","doc":"Creates a notification_endpoint.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#create_notification_endpoint/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.create_notification_endpoint/1","doc":"iex> create_notification_endpoint(%\n    {\n      endpoint_placeholder: endpoint_placeholder_value,\n      endpoint_url: endpoint_url_value,\n      endpoint_credentials (optional): \"username:password\"\n    })\n    {:ok, %NotificationEndpoint{}}\n\n    iex> create_notification_endpoint(%\n    {\n      endpoint_placeholder: bad_endpoint_placeholder_value,\n      endpoint_url: endpoint_url_value,\n      endpoint_credentials (optional): \"username:password\"\n    })\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#create_notification_endpoint/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.delete_notification_endpoint/1","doc":"Deletes a NotificationEndpoint.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#delete_notification_endpoint/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.delete_notification_endpoint/1","doc":"iex> delete_notification_endpoint(notification_endpoint)\n    {:ok, %NotificationEndpoint{}}\n\n    iex> delete_notification_endpoint(notification_endpoint)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#delete_notification_endpoint/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.get_notification_endpoint!/1","doc":"Gets a single notification_endpoint.\n\nRaises `Ecto.NoResultsError` if the notification_endpoint does not exist.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#get_notification_endpoint!/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.get_notification_endpoint!/1","doc":"iex> get_notification_endpoint!(123)\n    %NotificationEndpoint{}\n\n    iex> get_notification_endpoint!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#get_notification_endpoint!/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.get_notification_endpoint_by_placeholder/1","doc":"Gets a single notification_endpoint by endpoint_placeholder.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#get_notification_endpoint_by_placeholder/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.get_notification_endpoint_by_placeholder/1","doc":"iex> get_notification_endpoint_by_placeholder(\"MY_PLACEHOLDER\")\n    %NotificationEndpoint{}\n\n    iex> get_notification_endpoint_by_placeholder(\"BAD_PLACEHOLDER\")\n    nil","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#get_notification_endpoint_by_placeholder/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.list_notification_endpoints/1","doc":"Returns the list of notification endpoints.","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#list_notification_endpoints/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationEndpoints.list_notification_endpoints/1","doc":"iex> list_notification_endpoints()\n    [%NotificationEndpoint{}, ...]","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#list_notification_endpoints/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationEndpoints.update_notification_endpoint/2","doc":"","ref":"StepFlow.NotificationHooks.NotificationEndpoints.html#update_notification_endpoint/2"},{"type":"module","title":"StepFlow.NotificationHooks.NotificationHookManager","doc":"Notification manager context.","ref":"StepFlow.NotificationHooks.NotificationHookManager.html"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.get_last_status/1","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#get_last_status/1"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.manage_notification_status/3","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#manage_notification_status/3"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.notification_from_job/2","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#notification_from_job/2"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.notification_slack_from_job/4","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#notification_slack_from_job/4"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.notification_teams_from_job/5","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#notification_teams_from_job/5"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.notify_endpoint_with_status/7","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#notify_endpoint_with_status/7"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationHookManager.retrieve_status/8","doc":"","ref":"StepFlow.NotificationHooks.NotificationHookManager.html#retrieve_status/8"},{"type":"module","title":"StepFlow.NotificationHooks.NotificationTemplates","doc":"The Notification templates context.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.create_notification_template/1","doc":"Creates a notification_template.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#create_notification_template/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.create_notification_template/1","doc":"iex> create_notification_template(%\n    {\n      template_name: template_name_value,\n      template_headers: template_headers_value,\n      template_body: template_body_value\n    })\n    {:ok, %NotificationTemplate{}}\n\n    iex> create_notification_template(%\n    {\n      template_name: duplicate_template_name_value,\n      template_headers: template_headers_value,\n      template_body: template_body_value\n    })\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#create_notification_template/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.delete_notification_template/1","doc":"Deletes a NotificationTemplate.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#delete_notification_template/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.delete_notification_template/1","doc":"iex> delete_notification_template(notification_template)\n    {:ok, %NotificationTemplate{}}\n\n    iex> delete_notification_template(notification_template)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#delete_notification_template/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.get_notification_template!/1","doc":"Gets a single notification_template.\n\nRaises `Ecto.NoResultsError` if the notification_template does not exist.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#get_notification_template!/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.get_notification_template!/1","doc":"iex> get_notification_template!(123)\n    %NotificationTemplate{}\n\n    iex> get_notification_template!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#get_notification_template!/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.get_notification_template_by_name/1","doc":"Gets a single notification_template by template_name.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#get_notification_template_by_name/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.get_notification_template_by_name/1","doc":"iex> get_notification_template_by_name(\"MY_NAME\")\n    %NotificationTemplate{}\n\n    iex> get_notification_template_by_name(\"BAD_NAME\")\n    nil","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#get_notification_template_by_name/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.list_notification_templates/1","doc":"Returns the list of notification templates.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#list_notification_templates/1"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.list_notification_templates/1","doc":"iex> list_notification_templates()\n    [%NotificationTemplate{}, ...]","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#list_notification_templates/1-examples"},{"type":"function","title":"StepFlow.NotificationHooks.NotificationTemplates.update_notification_template/2","doc":"Updates NotificationTemplate.","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#update_notification_template/2"},{"type":"function","title":"Examples - StepFlow.NotificationHooks.NotificationTemplates.update_notification_template/2","doc":"iex> update_notification_template(notification_template, %{field: new_value})\n    {:ok, %NotificationTemplate{}}\n\n    iex> update_notification_template(notification_template, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.NotificationHooks.NotificationTemplates.html#update_notification_template/2-examples"},{"type":"module","title":"StepFlow.NotificationTemplateView","doc":"","ref":"StepFlow.NotificationTemplateView.html"},{"type":"function","title":"StepFlow.NotificationTemplateView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.NotificationTemplateView.html#__resource__/0"},{"type":"function","title":"StepFlow.NotificationTemplateView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.NotificationTemplateView.html#render/2"},{"type":"function","title":"StepFlow.NotificationTemplateView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.NotificationTemplateView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Progressions","doc":"The Progressions context.","ref":"StepFlow.Progressions.html"},{"type":"function","title":"StepFlow.Progressions.create_progression/1","doc":"Creates a progression.","ref":"StepFlow.Progressions.html#create_progression/1"},{"type":"function","title":"Examples - StepFlow.Progressions.create_progression/1","doc":"iex> create_progression(%{field: value})\n    {:ok, %Progression{}}\n\n    iex> create_progression(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Progressions.html#create_progression/1-examples"},{"type":"module","title":"StepFlow.ProgressionsView","doc":"","ref":"StepFlow.ProgressionsView.html"},{"type":"function","title":"StepFlow.ProgressionsView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.ProgressionsView.html#__resource__/0"},{"type":"function","title":"StepFlow.ProgressionsView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.ProgressionsView.html#render/2"},{"type":"function","title":"StepFlow.ProgressionsView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.ProgressionsView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Repo","doc":"","ref":"StepFlow.Repo.html"},{"type":"function","title":"StepFlow.Repo.aggregate/3","doc":"","ref":"StepFlow.Repo.html#aggregate/3"},{"type":"function","title":"StepFlow.Repo.aggregate/4","doc":"","ref":"StepFlow.Repo.html#aggregate/4"},{"type":"function","title":"StepFlow.Repo.all/2","doc":"","ref":"StepFlow.Repo.html#all/2"},{"type":"function","title":"StepFlow.Repo.bypass/1","doc":"","ref":"StepFlow.Repo.html#bypass/1"},{"type":"function","title":"StepFlow.Repo.checked_out?/0","doc":"","ref":"StepFlow.Repo.html#checked_out?/0"},{"type":"function","title":"StepFlow.Repo.checkout/2","doc":"","ref":"StepFlow.Repo.html#checkout/2"},{"type":"function","title":"StepFlow.Repo.child_spec/1","doc":"","ref":"StepFlow.Repo.html#child_spec/1"},{"type":"function","title":"StepFlow.Repo.config/0","doc":"","ref":"StepFlow.Repo.html#config/0"},{"type":"function","title":"StepFlow.Repo.default_options/1","doc":"","ref":"StepFlow.Repo.html#default_options/1"},{"type":"function","title":"StepFlow.Repo.delete/2","doc":"","ref":"StepFlow.Repo.html#delete/2"},{"type":"function","title":"StepFlow.Repo.delete!/2","doc":"","ref":"StepFlow.Repo.html#delete!/2"},{"type":"function","title":"StepFlow.Repo.delete_all/2","doc":"","ref":"StepFlow.Repo.html#delete_all/2"},{"type":"function","title":"StepFlow.Repo.disconnect_all/2","doc":"A convenience function for SQL-based repositories that forces all connections in the\npool to disconnect within the given interval.\n\nSee `Ecto.Adapters.SQL.disconnect_all/3` for more information.","ref":"StepFlow.Repo.html#disconnect_all/2"},{"type":"function","title":"StepFlow.Repo.exists?/2","doc":"","ref":"StepFlow.Repo.html#exists?/2"},{"type":"function","title":"StepFlow.Repo.explain/3","doc":"A convenience function for SQL-based repositories that executes an EXPLAIN statement or similar\ndepending on the adapter to obtain statistics for the given query.\n\nSee `Ecto.Adapters.SQL.explain/4` for more information.","ref":"StepFlow.Repo.html#explain/3"},{"type":"function","title":"StepFlow.Repo.get/3","doc":"","ref":"StepFlow.Repo.html#get/3"},{"type":"function","title":"StepFlow.Repo.get!/3","doc":"","ref":"StepFlow.Repo.html#get!/3"},{"type":"function","title":"StepFlow.Repo.get_by/3","doc":"","ref":"StepFlow.Repo.html#get_by/3"},{"type":"function","title":"StepFlow.Repo.get_by!/3","doc":"","ref":"StepFlow.Repo.html#get_by!/3"},{"type":"function","title":"StepFlow.Repo.get_dynamic_repo/0","doc":"","ref":"StepFlow.Repo.html#get_dynamic_repo/0"},{"type":"function","title":"StepFlow.Repo.in_transaction?/0","doc":"","ref":"StepFlow.Repo.html#in_transaction?/0"},{"type":"function","title":"StepFlow.Repo.init/2","doc":"","ref":"StepFlow.Repo.html#init/2"},{"type":"function","title":"StepFlow.Repo.insert/2","doc":"","ref":"StepFlow.Repo.html#insert/2"},{"type":"function","title":"StepFlow.Repo.insert!/2","doc":"","ref":"StepFlow.Repo.html#insert!/2"},{"type":"function","title":"StepFlow.Repo.insert_all/3","doc":"","ref":"StepFlow.Repo.html#insert_all/3"},{"type":"function","title":"StepFlow.Repo.insert_or_update/2","doc":"","ref":"StepFlow.Repo.html#insert_or_update/2"},{"type":"function","title":"StepFlow.Repo.insert_or_update!/2","doc":"","ref":"StepFlow.Repo.html#insert_or_update!/2"},{"type":"function","title":"StepFlow.Repo.load/2","doc":"","ref":"StepFlow.Repo.html#load/2"},{"type":"function","title":"StepFlow.Repo.one/2","doc":"","ref":"StepFlow.Repo.html#one/2"},{"type":"function","title":"StepFlow.Repo.one!/2","doc":"","ref":"StepFlow.Repo.html#one!/2"},{"type":"function","title":"StepFlow.Repo.preload/3","doc":"","ref":"StepFlow.Repo.html#preload/3"},{"type":"function","title":"StepFlow.Repo.prepare_query/3","doc":"","ref":"StepFlow.Repo.html#prepare_query/3"},{"type":"function","title":"StepFlow.Repo.put_dynamic_repo/1","doc":"","ref":"StepFlow.Repo.html#put_dynamic_repo/1"},{"type":"function","title":"StepFlow.Repo.query/3","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query/4` for more information.","ref":"StepFlow.Repo.html#query/3"},{"type":"function","title":"StepFlow.Repo.query!/3","doc":"A convenience function for SQL-based repositories that executes the given query.\n\nSee `Ecto.Adapters.SQL.query!/4` for more information.","ref":"StepFlow.Repo.html#query!/3"},{"type":"function","title":"StepFlow.Repo.query_many/3","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many/4` for more information.","ref":"StepFlow.Repo.html#query_many/3"},{"type":"function","title":"StepFlow.Repo.query_many!/3","doc":"A convenience function for SQL-based repositories that executes the given multi-result query.\n\nSee `Ecto.Adapters.SQL.query_many!/4` for more information.","ref":"StepFlow.Repo.html#query_many!/3"},{"type":"function","title":"StepFlow.Repo.reload/2","doc":"","ref":"StepFlow.Repo.html#reload/2"},{"type":"function","title":"StepFlow.Repo.reload!/2","doc":"","ref":"StepFlow.Repo.html#reload!/2"},{"type":"function","title":"StepFlow.Repo.rollback/1","doc":"","ref":"StepFlow.Repo.html#rollback/1"},{"type":"function","title":"StepFlow.Repo.start_link/1","doc":"","ref":"StepFlow.Repo.html#start_link/1"},{"type":"function","title":"StepFlow.Repo.stop/1","doc":"","ref":"StepFlow.Repo.html#stop/1"},{"type":"function","title":"StepFlow.Repo.stream/2","doc":"","ref":"StepFlow.Repo.html#stream/2"},{"type":"function","title":"StepFlow.Repo.to_sql/2","doc":"A convenience function for SQL-based repositories that translates the given query to SQL.\n\nSee `Ecto.Adapters.SQL.to_sql/3` for more information.","ref":"StepFlow.Repo.html#to_sql/2"},{"type":"function","title":"StepFlow.Repo.transaction/2","doc":"","ref":"StepFlow.Repo.html#transaction/2"},{"type":"function","title":"StepFlow.Repo.update/2","doc":"","ref":"StepFlow.Repo.html#update/2"},{"type":"function","title":"StepFlow.Repo.update!/2","doc":"","ref":"StepFlow.Repo.html#update!/2"},{"type":"function","title":"StepFlow.Repo.update_all/3","doc":"","ref":"StepFlow.Repo.html#update_all/3"},{"type":"module","title":"StepFlow.Repo.SupervisionTree","doc":"Dump the application supervision tree into the application logs.\nUseful for debugging purpose.","ref":"StepFlow.Repo.SupervisionTree.html"},{"type":"function","title":"StepFlow.Repo.SupervisionTree.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Repo.SupervisionTree.html#child_spec/1"},{"type":"function","title":"StepFlow.Repo.SupervisionTree.start_link/0","doc":"","ref":"StepFlow.Repo.SupervisionTree.html#start_link/0"},{"type":"module","title":"StepFlow.RightDefinitionView","doc":"","ref":"StepFlow.RightDefinitionView.html"},{"type":"function","title":"StepFlow.RightDefinitionView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.RightDefinitionView.html#__resource__/0"},{"type":"function","title":"StepFlow.RightDefinitionView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.RightDefinitionView.html#render/2"},{"type":"function","title":"StepFlow.RightDefinitionView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.RightDefinitionView.html#template_not_found/2"},{"type":"module","title":"StepFlow.RightView","doc":"","ref":"StepFlow.RightView.html"},{"type":"function","title":"StepFlow.RightView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.RightView.html#__resource__/0"},{"type":"function","title":"StepFlow.RightView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.RightView.html#render/2"},{"type":"function","title":"StepFlow.RightView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.RightView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Rights.Right","doc":"The Right context.","ref":"StepFlow.Rights.Right.html"},{"type":"function","title":"StepFlow.Rights.Right.cast/1","doc":"","ref":"StepFlow.Rights.Right.html#cast/1"},{"type":"function","title":"StepFlow.Rights.Right.dump/1","doc":"","ref":"StepFlow.Rights.Right.html#dump/1"},{"type":"function","title":"StepFlow.Rights.Right.embed_as/1","doc":"","ref":"StepFlow.Rights.Right.html#embed_as/1"},{"type":"function","title":"StepFlow.Rights.Right.equal?/2","doc":"","ref":"StepFlow.Rights.Right.html#equal?/2"},{"type":"function","title":"StepFlow.Rights.Right.load/1","doc":"","ref":"StepFlow.Rights.Right.html#load/1"},{"type":"function","title":"StepFlow.Rights.Right.type/0","doc":"","ref":"StepFlow.Rights.Right.html#type/0"},{"type":"module","title":"StepFlow.Rights.Right.EndpointEnum","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.cast/1","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#cast/1"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.dump/1","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#dump/1"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.embed_as/1","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#embed_as/1"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.equal?/2","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#equal?/2"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.load/1","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#load/1"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.type/0","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#type/0"},{"type":"function","title":"StepFlow.Rights.Right.EndpointEnum.valid_value?/1","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#valid_value?/1"},{"type":"type","title":"StepFlow.Rights.Right.EndpointEnum.t/0","doc":"","ref":"StepFlow.Rights.Right.EndpointEnum.html#t:t/0"},{"type":"module","title":"StepFlow.Rights.Right.RightEnum","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.cast/1","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#cast/1"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.dump/1","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#dump/1"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.embed_as/1","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#embed_as/1"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.equal?/2","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#equal?/2"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.load/1","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#load/1"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.type/0","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#type/0"},{"type":"function","title":"StepFlow.Rights.Right.RightEnum.valid_value?/1","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#valid_value?/1"},{"type":"type","title":"StepFlow.Rights.Right.RightEnum.t/0","doc":"","ref":"StepFlow.Rights.Right.RightEnum.html#t:t/0"},{"type":"module","title":"StepFlow.RoleView","doc":"","ref":"StepFlow.RoleView.html"},{"type":"function","title":"StepFlow.RoleView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.RoleView.html#__resource__/0"},{"type":"function","title":"StepFlow.RoleView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.RoleView.html#render/2"},{"type":"function","title":"StepFlow.RoleView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.RoleView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Roles","doc":"The Roles context.","ref":"StepFlow.Roles.html"},{"type":"function","title":"StepFlow.Roles.change_role/1","doc":"Returns an `%Ecto.Changeset{}` for tracking role changes.","ref":"StepFlow.Roles.html#change_role/1"},{"type":"function","title":"Examples - StepFlow.Roles.change_role/1","doc":"iex> change_role(role)\n    %Ecto.Changeset{source: %Role{}}","ref":"StepFlow.Roles.html#change_role/1-examples"},{"type":"function","title":"StepFlow.Roles.create_role/1","doc":"Creates a role.","ref":"StepFlow.Roles.html#create_role/1"},{"type":"function","title":"Examples - StepFlow.Roles.create_role/1","doc":"iex> create_role(%{field: value})\n    {:ok, %Role{}}\n\n    iex> create_role(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Roles.html#create_role/1-examples"},{"type":"function","title":"StepFlow.Roles.delete_role/1","doc":"Deletes a Role.","ref":"StepFlow.Roles.html#delete_role/1"},{"type":"function","title":"Examples - StepFlow.Roles.delete_role/1","doc":"iex> delete_role(role)\n    {:ok, %Role{}}\n\n    iex> delete_role(role)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Roles.html#delete_role/1-examples"},{"type":"function","title":"StepFlow.Roles.get_by/1","doc":"Gets a single role by name","ref":"StepFlow.Roles.html#get_by/1"},{"type":"function","title":"Examples - StepFlow.Roles.get_by/1","doc":"iex> get_by(toto)\n    %Role{}\n\n    iex> get_by(tata)\n    nil","ref":"StepFlow.Roles.html#get_by/1-examples"},{"type":"function","title":"StepFlow.Roles.get_by!/1","doc":"Gets a single role by name","ref":"StepFlow.Roles.html#get_by!/1"},{"type":"function","title":"Examples - StepFlow.Roles.get_by!/1","doc":"iex> get_by!(toto)\n    %Role{}\n\n    iex> get_by!(tata)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Roles.html#get_by!/1-examples"},{"type":"function","title":"StepFlow.Roles.get_role/1","doc":"Gets a single role.","ref":"StepFlow.Roles.html#get_role/1"},{"type":"function","title":"Examples - StepFlow.Roles.get_role/1","doc":"iex> get_role(123)\n    %Role{}\n\n    iex> get_role(456)\n    nil","ref":"StepFlow.Roles.html#get_role/1-examples"},{"type":"function","title":"StepFlow.Roles.get_role!/1","doc":"Gets a single role.\n\nRaises `Ecto.NoResultsError` if the Role does not exist.","ref":"StepFlow.Roles.html#get_role!/1"},{"type":"function","title":"Examples - StepFlow.Roles.get_role!/1","doc":"iex> get_role!(123)\n    %Role{}\n\n    iex> get_role!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Roles.html#get_role!/1-examples"},{"type":"function","title":"StepFlow.Roles.get_roles/2","doc":"Gets a several roles.","ref":"StepFlow.Roles.html#get_roles/2"},{"type":"function","title":"Examples - StepFlow.Roles.get_roles/2","doc":"iex> get_roles([\"toto\", \"tata\"])\n    [%Role{}, %Role{}]","ref":"StepFlow.Roles.html#get_roles/2-examples"},{"type":"function","title":"StepFlow.Roles.list_roles/1","doc":"Returns the list of roles.","ref":"StepFlow.Roles.html#list_roles/1"},{"type":"function","title":"Examples - StepFlow.Roles.list_roles/1","doc":"iex> list_roles()\n    [%Role{}, ...]","ref":"StepFlow.Roles.html#list_roles/1-examples"},{"type":"function","title":"StepFlow.Roles.update_role/2","doc":"Updates a role.","ref":"StepFlow.Roles.html#update_role/2"},{"type":"function","title":"Examples - StepFlow.Roles.update_role/2","doc":"iex> update_role(role, %{field: new_value})\n    {:ok, %Job{}}\n\n    iex> update_role(role, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Roles.html#update_role/2-examples"},{"type":"module","title":"StepFlow.Router","doc":"","ref":"StepFlow.Router.html"},{"type":"function","title":"StepFlow.Router.api/2","doc":"","ref":"StepFlow.Router.html#api/2"},{"type":"function","title":"StepFlow.Router.call/2","doc":"Callback invoked by Plug on every request.","ref":"StepFlow.Router.html#call/2"},{"type":"function","title":"StepFlow.Router.init/1","doc":"Callback required by Plug that initializes the router\nfor serving web requests.","ref":"StepFlow.Router.html#init/1"},{"type":"module","title":"StepFlow.SlackBot","doc":"Bot connected to Slack if the token is provided.\n\nIt allow to send notifications to channel.","ref":"StepFlow.SlackBot.html"},{"type":"function","title":"StepFlow.SlackBot.child_spec/1","doc":"","ref":"StepFlow.SlackBot.html#child_spec/1"},{"type":"function","title":"StepFlow.SlackBot.handle_close/3","doc":"","ref":"StepFlow.SlackBot.html#handle_close/3"},{"type":"function","title":"StepFlow.SlackBot.handle_connect/2","doc":"","ref":"StepFlow.SlackBot.html#handle_connect/2"},{"type":"function","title":"StepFlow.SlackBot.handle_event/3","doc":"","ref":"StepFlow.SlackBot.html#handle_event/3"},{"type":"function","title":"StepFlow.SlackBot.handle_info/3","doc":"","ref":"StepFlow.SlackBot.html#handle_info/3"},{"type":"module","title":"StepFlow.Statistics.Helpers","doc":"The Helper Step context.","ref":"StepFlow.Statistics.Helpers.html"},{"type":"function","title":"StepFlow.Statistics.Helpers.limit_duration_to_milliseconds/1","doc":"","ref":"StepFlow.Statistics.Helpers.html#limit_duration_to_milliseconds/1"},{"type":"module","title":"StepFlow.Statistics.JobsDurations","doc":"The JobsStatistics context.","ref":"StepFlow.Statistics.JobsDurations.html"},{"type":"function","title":"StepFlow.Statistics.JobsDurations.create_job_durations/1","doc":"Creates a job durations.","ref":"StepFlow.Statistics.JobsDurations.html#create_job_durations/1"},{"type":"function","title":"Examples - StepFlow.Statistics.JobsDurations.create_job_durations/1","doc":"iex> create_job_durations(%{field: value})\n    {:ok, %JobDurations{}}\n\n    iex> create_job_durations(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Statistics.JobsDurations.html#create_job_durations/1-examples"},{"type":"function","title":"StepFlow.Statistics.JobsDurations.get_by/1","doc":"","ref":"StepFlow.Statistics.JobsDurations.html#get_by/1"},{"type":"function","title":"StepFlow.Statistics.JobsDurations.set_job_durations/1","doc":"","ref":"StepFlow.Statistics.JobsDurations.html#set_job_durations/1"},{"type":"function","title":"StepFlow.Statistics.JobsDurations.update_job_durations/2","doc":"Updates a job durations.","ref":"StepFlow.Statistics.JobsDurations.html#update_job_durations/2"},{"type":"function","title":"Examples - StepFlow.Statistics.JobsDurations.update_job_durations/2","doc":"iex> update_job_durations(job_durations, %{field: new_value})\n    {:ok, %JobDurations{}}\n\n    iex> update_job_durations(job_durations, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Statistics.JobsDurations.html#update_job_durations/2-examples"},{"type":"module","title":"StepFlow.StatusView","doc":"","ref":"StepFlow.StatusView.html"},{"type":"function","title":"StepFlow.StatusView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.StatusView.html#__resource__/0"},{"type":"function","title":"StepFlow.StatusView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.StatusView.html#render/2"},{"type":"function","title":"StepFlow.StatusView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.StatusView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Step","doc":"The Step context.","ref":"StepFlow.Step.html"},{"type":"function","title":"StepFlow.Step.abort_step_jobs/2","doc":"","ref":"StepFlow.Step.html#abort_step_jobs/2"},{"type":"function","title":"StepFlow.Step.pause_step/3","doc":"","ref":"StepFlow.Step.html#pause_step/3"},{"type":"function","title":"StepFlow.Step.resume_step/1","doc":"","ref":"StepFlow.Step.html#resume_step/1"},{"type":"function","title":"StepFlow.Step.skip_step/2","doc":"","ref":"StepFlow.Step.html#skip_step/2"},{"type":"function","title":"StepFlow.Step.skip_step_jobs/2","doc":"","ref":"StepFlow.Step.html#skip_step_jobs/2"},{"type":"function","title":"StepFlow.Step.start_next/1","doc":"","ref":"StepFlow.Step.html#start_next/1"},{"type":"module","title":"StepFlow.Step.Helpers","doc":"The Helper Step context.","ref":"StepFlow.Step.Helpers.html"},{"type":"function","title":"StepFlow.Step.Helpers.add_required_paths/2","doc":"","ref":"StepFlow.Step.Helpers.html#add_required_paths/2"},{"type":"function","title":"StepFlow.Step.Helpers.filter_empty/1","doc":"","ref":"StepFlow.Step.Helpers.html#filter_empty/1"},{"type":"function","title":"StepFlow.Step.Helpers.filter_empty_templated/1","doc":"","ref":"StepFlow.Step.Helpers.html#filter_empty_templated/1"},{"type":"function","title":"StepFlow.Step.Helpers.filter_path_list/2","doc":"Filter a list of paths.","ref":"StepFlow.Step.Helpers.html#filter_path_list/2"},{"type":"function","title":"Examples - StepFlow.Step.Helpers.filter_path_list/2","doc":"iex> StepFlow.Step.Helpers.filter_path_list([\"path_1.ext1\", \"path2.ext2\"], [%{\"ends_with\" => \".ext2\"}])\n    [\"path2.ext2\"]\n\n    iex> StepFlow.Step.Helpers.filter_path_list([\"path_1.ext1\", \"path2.ext2\"], [%{ends_with: \".ext2\"}])\n    [\"path2.ext2\"]","ref":"StepFlow.Step.Helpers.html#filter_path_list/2-examples"},{"type":"function","title":"StepFlow.Step.Helpers.filter_untemplated/1","doc":"","ref":"StepFlow.Step.Helpers.html#filter_untemplated/1"},{"type":"function","title":"StepFlow.Step.Helpers.get_base_directory/2","doc":"","ref":"StepFlow.Step.Helpers.html#get_base_directory/2"},{"type":"function","title":"StepFlow.Step.Helpers.get_dates/0","doc":"","ref":"StepFlow.Step.Helpers.html#get_dates/0"},{"type":"function","title":"StepFlow.Step.Helpers.get_job_destination_paths/1","doc":"","ref":"StepFlow.Step.Helpers.html#get_job_destination_paths/1"},{"type":"function","title":"StepFlow.Step.Helpers.get_jobs_destination_paths/1","doc":"","ref":"StepFlow.Step.Helpers.html#get_jobs_destination_paths/1"},{"type":"function","title":"StepFlow.Step.Helpers.get_required_paths/2","doc":"","ref":"StepFlow.Step.Helpers.html#get_required_paths/2"},{"type":"function","title":"StepFlow.Step.Helpers.get_step_requirements/2","doc":"","ref":"StepFlow.Step.Helpers.html#get_step_requirements/2"},{"type":"function","title":"StepFlow.Step.Helpers.get_string_or_processed_template_value/6","doc":"","ref":"StepFlow.Step.Helpers.html#get_string_or_processed_template_value/6"},{"type":"function","title":"StepFlow.Step.Helpers.get_value_in_parameters/2","doc":"Retrieves a value on an Objecta and filtered by the key.","ref":"StepFlow.Step.Helpers.html#get_value_in_parameters/2"},{"type":"function","title":"StepFlow.Step.Helpers.get_value_in_parameters_with_type/3","doc":"Retrieves a value on an Object and filtered by the key and type.","ref":"StepFlow.Step.Helpers.html#get_value_in_parameters_with_type/3"},{"type":"function","title":"StepFlow.Step.Helpers.get_work_directory/1","doc":"","ref":"StepFlow.Step.Helpers.html#get_work_directory/1"},{"type":"function","title":"StepFlow.Step.Helpers.template_process/5","doc":"","ref":"StepFlow.Step.Helpers.html#template_process/5"},{"type":"function","title":"StepFlow.Step.Helpers.templates_process/5","doc":"","ref":"StepFlow.Step.Helpers.html#templates_process/5"},{"type":"module","title":"StepFlow.Step.Launch","doc":"The Step launcher context.","ref":"StepFlow.Step.Launch.html"},{"type":"function","title":"StepFlow.Step.Launch.build_requirements_and_destination_path/8","doc":"","ref":"StepFlow.Step.Launch.html#build_requirements_and_destination_path/8"},{"type":"function","title":"StepFlow.Step.Launch.filter_and_pre_compile_parameters/5","doc":"","ref":"StepFlow.Step.Launch.html#filter_and_pre_compile_parameters/5"},{"type":"function","title":"StepFlow.Step.Launch.get_required_paths/4","doc":"","ref":"StepFlow.Step.Launch.html#get_required_paths/4"},{"type":"function","title":"StepFlow.Step.Launch.get_source_paths/3","doc":"","ref":"StepFlow.Step.Launch.html#get_source_paths/3"},{"type":"function","title":"StepFlow.Step.Launch.launch_step/2","doc":"","ref":"StepFlow.Step.Launch.html#launch_step/2"},{"type":"module","title":"StepFlow.Step.LaunchJobs","doc":"The Step Jobs launching parameters.","ref":"StepFlow.Step.LaunchJobs.html"},{"type":"function","title":"StepFlow.Step.LaunchJobs.generate_job_one_for_many/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#generate_job_one_for_many/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.generate_job_one_for_one/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#generate_job_one_for_one/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.generate_job_parameters_one_for_one/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#generate_job_parameters_one_for_one/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.generate_message_one_for_many/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#generate_message_one_for_many/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.generate_message_one_for_one/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#generate_message_one_for_one/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.start_job/1","doc":"","ref":"StepFlow.Step.LaunchJobs.html#start_job/1"},{"type":"function","title":"StepFlow.Step.LaunchJobs.start_job_one_for_many/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#start_job_one_for_many/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.start_job_one_for_one/2","doc":"","ref":"StepFlow.Step.LaunchJobs.html#start_job_one_for_one/2"},{"type":"function","title":"StepFlow.Step.LaunchJobs.start_multiple_jobs_one_for_one/3","doc":"","ref":"StepFlow.Step.LaunchJobs.html#start_multiple_jobs_one_for_one/3"},{"type":"module","title":"StepFlow.Step.LaunchParams","doc":"The Step launching parameters.","ref":"StepFlow.Step.LaunchParams.html"},{"type":"function","title":"StepFlow.Step.LaunchParams.get_step_allow_failure/1","doc":"","ref":"StepFlow.Step.LaunchParams.html#get_step_allow_failure/1"},{"type":"function","title":"StepFlow.Step.LaunchParams.get_step_id/1","doc":"","ref":"StepFlow.Step.LaunchParams.html#get_step_id/1"},{"type":"function","title":"StepFlow.Step.LaunchParams.get_step_name/1","doc":"","ref":"StepFlow.Step.LaunchParams.html#get_step_name/1"},{"type":"function","title":"StepFlow.Step.LaunchParams.get_step_parameter/2","doc":"","ref":"StepFlow.Step.LaunchParams.html#get_step_parameter/2"},{"type":"function","title":"StepFlow.Step.LaunchParams.new/3","doc":"","ref":"StepFlow.Step.LaunchParams.html#new/3"},{"type":"function","title":"StepFlow.Step.LaunchParams.new/4","doc":"","ref":"StepFlow.Step.LaunchParams.html#new/4"},{"type":"function","title":"StepFlow.Step.LaunchParams.new/5","doc":"","ref":"StepFlow.Step.LaunchParams.html#new/5"},{"type":"module","title":"StepFlow.Step.LaunchWorkflows","doc":"The Step Workflows launching parameters.","ref":"StepFlow.Step.LaunchWorkflows.html"},{"type":"function","title":"StepFlow.Step.LaunchWorkflows.generate_child_workflow_job/2","doc":"","ref":"StepFlow.Step.LaunchWorkflows.html#generate_child_workflow_job/2"},{"type":"function","title":"StepFlow.Step.LaunchWorkflows.generate_child_workflow_params/5","doc":"","ref":"StepFlow.Step.LaunchWorkflows.html#generate_child_workflow_params/5"},{"type":"function","title":"StepFlow.Step.LaunchWorkflows.start_child_workflow_one_for_many/4","doc":"","ref":"StepFlow.Step.LaunchWorkflows.html#start_child_workflow_one_for_many/4"},{"type":"function","title":"StepFlow.Step.LaunchWorkflows.start_child_workflows_one_for_one/4","doc":"","ref":"StepFlow.Step.LaunchWorkflows.html#start_child_workflows_one_for_one/4"},{"type":"module","title":"StepFlow.Step.Live","doc":"The Live step context.","ref":"StepFlow.Step.Live.html"},{"type":"function","title":"StepFlow.Step.Live.create_job_live/2","doc":"","ref":"StepFlow.Step.Live.html#create_job_live/2"},{"type":"function","title":"StepFlow.Step.Live.generate_message/2","doc":"","ref":"StepFlow.Step.Live.html#generate_message/2"},{"type":"function","title":"StepFlow.Step.Live.generate_message_live/2","doc":"","ref":"StepFlow.Step.Live.html#generate_message_live/2"},{"type":"function","title":"StepFlow.Step.Live.stop_jobs/1","doc":"","ref":"StepFlow.Step.Live.html#stop_jobs/1"},{"type":"function","title":"StepFlow.Step.Live.update_job_live/1","doc":"","ref":"StepFlow.Step.Live.html#update_job_live/1"},{"type":"module","title":"StepFlow.Updates","doc":"The Updates context.","ref":"StepFlow.Updates.html"},{"type":"function","title":"StepFlow.Updates.create_update/1","doc":"Creates an update.","ref":"StepFlow.Updates.html#create_update/1"},{"type":"function","title":"Examples - StepFlow.Updates.create_update/1","doc":"iex> create_update(%{field: value})\n    {:ok, %Update{}}\n\n    iex> create_update(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Updates.html#create_update/1-examples"},{"type":"function","title":"StepFlow.Updates.update_parameters/2","doc":"","ref":"StepFlow.Updates.html#update_parameters/2"},{"type":"module","title":"StepFlow.UpdatesView","doc":"","ref":"StepFlow.UpdatesView.html"},{"type":"function","title":"StepFlow.UpdatesView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.UpdatesView.html#__resource__/0"},{"type":"function","title":"StepFlow.UpdatesView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.UpdatesView.html#render/2"},{"type":"function","title":"StepFlow.UpdatesView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.UpdatesView.html#template_not_found/2"},{"type":"module","title":"StepFlow.WebController.Fallback","doc":"Translates controller action results into valid `Plug.Conn` responses.\n\nSee `Phoenix.Controller.action_fallback/1` for more details.","ref":"StepFlow.WebController.Fallback.html"},{"type":"module","title":"StepFlow.WebController.Helpers","doc":"The Helper Controller context.","ref":"StepFlow.WebController.Helpers.html"},{"type":"function","title":"StepFlow.WebController.Helpers.has_right?/3","doc":"Check whether a user is allowed to use a rightable structure","ref":"StepFlow.WebController.Helpers.html#has_right?/3"},{"type":"module","title":"StepFlow.WorkerDefinitionView","doc":"","ref":"StepFlow.WorkerDefinitionView.html"},{"type":"function","title":"StepFlow.WorkerDefinitionView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.WorkerDefinitionView.html#__resource__/0"},{"type":"function","title":"StepFlow.WorkerDefinitionView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.WorkerDefinitionView.html#render/2"},{"type":"function","title":"StepFlow.WorkerDefinitionView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.WorkerDefinitionView.html#template_not_found/2"},{"type":"module","title":"StepFlow.WorkerDefinitions","doc":"The WorkerDefinitions context.","ref":"StepFlow.WorkerDefinitions.html"},{"type":"function","title":"StepFlow.WorkerDefinitions.create_worker_definition/1","doc":"Creates a WorkerDefinition.","ref":"StepFlow.WorkerDefinitions.html#create_worker_definition/1"},{"type":"function","title":"Examples - StepFlow.WorkerDefinitions.create_worker_definition/1","doc":"iex> result = StepFlow.WorkerDefinitions.create_worker_definition(%{\n    ...>   queue_name: \"my_queue\",\n    ...>   label: \"My Queue\",\n    ...>   version: \"1.2.3\",\n    ...>   short_description: \"short description\",\n    ...>   description: \"long description\",\n    ...>   parameters: %{}\n    ...> })\n    ...> match?({:ok, %StepFlow.WorkerDefinitions.WorkerDefinition{}}, result)\n    true\n\n    iex> result = StepFlow.WorkerDefinitions.create_worker_definition(%{field: :bad_value})\n    ...> match?({:error, %Ecto.Changeset{}}, result)\n    true","ref":"StepFlow.WorkerDefinitions.html#create_worker_definition/1-examples"},{"type":"function","title":"StepFlow.WorkerDefinitions.exists?/1","doc":"","ref":"StepFlow.WorkerDefinitions.html#exists?/1"},{"type":"function","title":"StepFlow.WorkerDefinitions.get_worker_definition!/1","doc":"Gets a single WorkerDefinition.\n\nRaises `Ecto.NoResultsError` if the WorkerDefinition does not exist.","ref":"StepFlow.WorkerDefinitions.html#get_worker_definition!/1"},{"type":"function","title":"StepFlow.WorkerDefinitions.list_worker_definitions/1","doc":"Returns the list of WorkerDefinitions.","ref":"StepFlow.WorkerDefinitions.html#list_worker_definitions/1"},{"type":"function","title":"Examples - StepFlow.WorkerDefinitions.list_worker_definitions/1","doc":"iex> StepFlow.WorkerDefinitions.list_worker_definitions()\n    %{data: [], page: 0, size: 10, total: 0}","ref":"StepFlow.WorkerDefinitions.html#list_worker_definitions/1-examples"},{"type":"module","title":"StepFlow.WorkerStatusView","doc":"","ref":"StepFlow.WorkerStatusView.html"},{"type":"function","title":"StepFlow.WorkerStatusView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.WorkerStatusView.html#__resource__/0"},{"type":"function","title":"StepFlow.WorkerStatusView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.WorkerStatusView.html#render/2"},{"type":"function","title":"StepFlow.WorkerStatusView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.WorkerStatusView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Workers.WorkerStatus.ActivityEnum","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.cast/1","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#cast/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.dump/1","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#dump/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.embed_as/1","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#embed_as/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.equal?/2","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#equal?/2"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.load/1","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#load/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.type/0","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#type/0"},{"type":"function","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.valid_value?/1","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#valid_value?/1"},{"type":"type","title":"StepFlow.Workers.WorkerStatus.ActivityEnum.t/0","doc":"","ref":"StepFlow.Workers.WorkerStatus.ActivityEnum.html#t:t/0"},{"type":"module","title":"StepFlow.Workers.WorkerStatus.JobStatus","doc":"","ref":"StepFlow.Workers.WorkerStatus.JobStatus.html"},{"type":"module","title":"StepFlow.Workers.WorkerStatuses","doc":"The WorkerStatuses context.","ref":"StepFlow.Workers.WorkerStatuses.html"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.create_worker_status/1","doc":"Creates a WorkerStatus.","ref":"StepFlow.Workers.WorkerStatuses.html#create_worker_status/1"},{"type":"function","title":"Examples - StepFlow.Workers.WorkerStatuses.create_worker_status/1","doc":"iex> result = StepFlow.Workers.WorkerStatuses.create_worker_status!(%{\n    ...>    job: nil,\n    ...>    worker: %{\n    ...>      activity: \"Idle\",\n    ...>      description: \"This worker is just an example.\",\n    ...>      direct_messaging_queue_name: \"direct_messaging_e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      instance_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      label: \"UnitTestWorker\",\n    ...>      queue_name: \"job_test_worker\",\n    ...>      sdk_version: \"2.3.4\",\n    ...>      short_description: \"A test worker\",\n    ...>      system_info: %{\n    ...>        docker_container_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>        number_of_processors: 12,\n    ...>        total_memory: 16_574_754,\n    ...>        total_swap: 2_046_816,\n    ...>        used_memory: 8_865_633,\n    ...>        used_swap: 0\n    ...>      },\n    ...>      version: \"1.2.3\"\n    ...>    }\n    ...> })\n    ...> match?(%StepFlow.Workers.WorkerStatus{}, result)\n    true\n\nReturns `{:ok, WorkerStatus}` on success, `{:error, changeset}` otherwise.","ref":"StepFlow.Workers.WorkerStatuses.html#create_worker_status/1-examples"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.create_worker_status!/1","doc":"Creates a WorkerStatus.","ref":"StepFlow.Workers.WorkerStatuses.html#create_worker_status!/1"},{"type":"function","title":"Examples - StepFlow.Workers.WorkerStatuses.create_worker_status!/1","doc":"iex> result = StepFlow.Workers.WorkerStatuses.create_worker_status!(%{\n    ...>    job: nil,\n    ...>    worker: %{\n    ...>      activity: \"Idle\",\n    ...>      description: \"This worker is just an example.\",\n    ...>      direct_messaging_queue_name: \"direct_messaging_e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      instance_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      label: \"UnitTestWorker\",\n    ...>      queue_name: \"job_test_worker\",\n    ...>      sdk_version: \"2.3.4\",\n    ...>      short_description: \"A test worker\",\n    ...>      system_info: %{\n    ...>        docker_container_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>        number_of_processors: 12,\n    ...>        total_memory: 16_574_754,\n    ...>        total_swap: 2_046_816,\n    ...>        used_memory: 8_865_633,\n    ...>        used_swap: 0\n    ...>      },\n    ...>      version: \"1.2.3\"\n    ...>    }\n    ...> })\n    ...> match?(%StepFlow.Workers.WorkerStatus{}, result)\n    true\n\nRaises error if something went wrong during creation.","ref":"StepFlow.Workers.WorkerStatuses.html#create_worker_status!/1-examples"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.get_worker_status/1","doc":"Gets the last inserted WorkerStatus.\n\nReturns `nil` if the Worker does not exist.","ref":"StepFlow.Workers.WorkerStatuses.html#get_worker_status/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.get_worker_status!/1","doc":"Gets the last inserted WorkerStatus.\n\n\nRaises `Ecto.NoResultsError` if the WorkerStatus does not exist.","ref":"StepFlow.Workers.WorkerStatuses.html#get_worker_status!/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.get_worker_status_for_job/1","doc":"Gets the first WorkerStatus which is running a job which ID is `job_id`.\n\nReturns `nil` if that WorkerStatus does not exist.","ref":"StepFlow.Workers.WorkerStatuses.html#get_worker_status_for_job/1"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.list_worker_statuses/1","doc":"Returns the list of WorkerStatuses.","ref":"StepFlow.Workers.WorkerStatuses.html#list_worker_statuses/1"},{"type":"function","title":"Examples - StepFlow.Workers.WorkerStatuses.list_worker_statuses/1","doc":"iex> StepFlow.WorkerStatuses.list_worker_statuses()\n    %{data: [], page: 0, size: 10, total: 0}","ref":"StepFlow.Workers.WorkerStatuses.html#list_worker_statuses/1-examples"},{"type":"function","title":"StepFlow.Workers.WorkerStatuses.update_worker_status!/2","doc":"Updates a WorkerStatus.","ref":"StepFlow.Workers.WorkerStatuses.html#update_worker_status!/2"},{"type":"function","title":"Examples - StepFlow.Workers.WorkerStatuses.update_worker_status!/2","doc":"iex> result = StepFlow.Workers.WorkerStatuses.update_worker_status!(%{\n    ...>    job: %{\n    ...>      destination_paths: [],\n    ...>      execution_duration: 0.0,\n    ...>      job_id: 1234,\n    ...>      parameters: [],\n    ...>      status: \"processing\"\n    ...>    },\n    ...>    worker: %{\n    ...>      activity: \"Idle\",\n    ...>      description: \"This worker is just an example.\",\n    ...>      direct_messaging_queue_name: \"direct_messaging_e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      instance_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>      label: \"UnitTestWorker\",\n    ...>      queue_name: \"job_test_worker\",\n    ...>      sdk_version: \"2.3.4\",\n    ...>      short_description: \"A test worker\",\n    ...>      system_info: %{\n    ...>        docker_container_id: \"e1297fe6-fe94-49cf-9ef8-1a751cba28f2\",\n    ...>        number_of_processors: 12,\n    ...>        total_memory: 16_574_754,\n    ...>        total_swap: 2_046_816,\n    ...>        used_memory: 8_865_633,\n    ...>        used_swap: 0\n    ...>      },\n    ...>      version: \"1.2.3\"\n    ...>    }\n    ...> })\n    ...> match?(%StepFlow.Workers.WorkerStatus{}, result)\n    true\n\nRaises error if something went wrong during update.","ref":"StepFlow.Workers.WorkerStatuses.html#update_worker_status!/2-examples"},{"type":"module","title":"StepFlow.WorkflowDefinitionView","doc":"","ref":"StepFlow.WorkflowDefinitionView.html"},{"type":"function","title":"StepFlow.WorkflowDefinitionView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.WorkflowDefinitionView.html#__resource__/0"},{"type":"function","title":"StepFlow.WorkflowDefinitionView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.WorkflowDefinitionView.html#render/2"},{"type":"function","title":"StepFlow.WorkflowDefinitionView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.WorkflowDefinitionView.html#template_not_found/2"},{"type":"module","title":"StepFlow.WorkflowDefinitions","doc":"The WorkflowDefinitions context.","ref":"StepFlow.WorkflowDefinitions.html"},{"type":"function","title":"StepFlow.WorkflowDefinitions.delete_by_id/1","doc":"","ref":"StepFlow.WorkflowDefinitions.html#delete_by_id/1"},{"type":"function","title":"StepFlow.WorkflowDefinitions.filter_by_versions/2","doc":"","ref":"StepFlow.WorkflowDefinitions.html#filter_by_versions/2"},{"type":"function","title":"StepFlow.WorkflowDefinitions.get_workflow_definition/1","doc":"Gets a single WorkflowDefinition (latest version).\n\nReturns nil if the WorkflowDefinition does not exist.","ref":"StepFlow.WorkflowDefinitions.html#get_workflow_definition/1"},{"type":"function","title":"StepFlow.WorkflowDefinitions.get_workflow_definition/4","doc":"Gets a single WorkflowDefinition by specifying the version.\n\nReturns nil if the WorkflowDefinition does not exist.","ref":"StepFlow.WorkflowDefinitions.html#get_workflow_definition/4"},{"type":"function","title":"StepFlow.WorkflowDefinitions.list_workflow_definitions/1","doc":"Returns the list of Workflow Definitions.","ref":"StepFlow.WorkflowDefinitions.html#list_workflow_definitions/1"},{"type":"function","title":"StepFlow.WorkflowDefinitions.load_workflow_in_database/1","doc":"","ref":"StepFlow.WorkflowDefinitions.html#load_workflow_in_database/1"},{"type":"function","title":"StepFlow.WorkflowDefinitions.load_workflows/0","doc":"Loads workflows","ref":"StepFlow.WorkflowDefinitions.html#load_workflows/0"},{"type":"function","title":"StepFlow.WorkflowDefinitions.load_workflows_in_database/0","doc":"Loads workflows in database","ref":"StepFlow.WorkflowDefinitions.html#load_workflows_in_database/0"},{"type":"module","title":"StepFlow.WorkflowDefinitions.ExternalLoader","doc":"Loader for referenced JSON schema implemented through Xema loader.","ref":"StepFlow.WorkflowDefinitions.ExternalLoader.html"},{"type":"function","title":"StepFlow.WorkflowDefinitions.ExternalLoader.fetch/1","doc":"","ref":"StepFlow.WorkflowDefinitions.ExternalLoader.html#fetch/1"},{"type":"module","title":"StepFlow.WorkflowDefinitions.WorkflowDefinition","doc":"The WorkflowDefinition context.","ref":"StepFlow.WorkflowDefinitions.WorkflowDefinition.html"},{"type":"module","title":"StepFlow.WorkflowStatusView","doc":"","ref":"StepFlow.WorkflowStatusView.html"},{"type":"function","title":"StepFlow.WorkflowStatusView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.WorkflowStatusView.html#__resource__/0"},{"type":"function","title":"StepFlow.WorkflowStatusView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.WorkflowStatusView.html#render/2"},{"type":"function","title":"StepFlow.WorkflowStatusView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.WorkflowStatusView.html#template_not_found/2"},{"type":"module","title":"StepFlow.WorkflowView","doc":"","ref":"StepFlow.WorkflowView.html"},{"type":"function","title":"StepFlow.WorkflowView.__resource__/0","doc":"The resource name, as an atom, for this view","ref":"StepFlow.WorkflowView.html#__resource__/0"},{"type":"function","title":"StepFlow.WorkflowView.render/2","doc":"Renders the given template locally.","ref":"StepFlow.WorkflowView.html#render/2"},{"type":"function","title":"StepFlow.WorkflowView.template_not_found/2","doc":"Callback invoked when no template is found.\nBy default it raises but can be customized\nto render a particular template.","ref":"StepFlow.WorkflowView.html#template_not_found/2"},{"type":"module","title":"StepFlow.Workflows","doc":"The Workflows context.","ref":"StepFlow.Workflows.html"},{"type":"function","title":"StepFlow.Workflows.abort/1","doc":"","ref":"StepFlow.Workflows.html#abort/1"},{"type":"function","title":"StepFlow.Workflows.apply_default_query_filters/2","doc":"","ref":"StepFlow.Workflows.html#apply_default_query_filters/2"},{"type":"function","title":"StepFlow.Workflows.change_workflow/1","doc":"Returns an `%Ecto.Changeset{}` for tracking workflow changes.","ref":"StepFlow.Workflows.html#change_workflow/1"},{"type":"function","title":"Examples - StepFlow.Workflows.change_workflow/1","doc":"iex> change_workflow(workflow)\n    %Ecto.Changeset{source: %Workflow{}}","ref":"StepFlow.Workflows.html#change_workflow/1-examples"},{"type":"function","title":"StepFlow.Workflows.check_rights/1","doc":"","ref":"StepFlow.Workflows.html#check_rights/1"},{"type":"function","title":"StepFlow.Workflows.create_workflow/1","doc":"Creates a workflow.","ref":"StepFlow.Workflows.html#create_workflow/1"},{"type":"function","title":"Examples - StepFlow.Workflows.create_workflow/1","doc":"iex> create_workflow(%{field: value})\n    {:ok, %Workflow{}}\n\n    iex> create_workflow(%{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Workflows.html#create_workflow/1-examples"},{"type":"function","title":"StepFlow.Workflows.delete_workflow/1","doc":"Deletes a Workflow.","ref":"StepFlow.Workflows.html#delete_workflow/1"},{"type":"function","title":"Examples - StepFlow.Workflows.delete_workflow/1","doc":"iex> delete_workflow(workflow)\n    {:ok, %Workflow{}}\n\n    iex> delete_workflow(workflow)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Workflows.html#delete_workflow/1-examples"},{"type":"function","title":"StepFlow.Workflows.duplicate_workflow/2","doc":"Duplicates a Workflow.","ref":"StepFlow.Workflows.html#duplicate_workflow/2"},{"type":"function","title":"Examples - StepFlow.Workflows.duplicate_workflow/2","doc":"iex> duplicate_workflow(workflow_id, user_uuid)\n    {:ok, Integer}\n\n    iex> duplicate_workflow(workflow_id, user_uuid)\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Workflows.html#duplicate_workflow/2-examples"},{"type":"function","title":"StepFlow.Workflows.filter_status/4","doc":"","ref":"StepFlow.Workflows.html#filter_status/4"},{"type":"function","title":"StepFlow.Workflows.get_completed_statistics/2","doc":"","ref":"StepFlow.Workflows.html#get_completed_statistics/2"},{"type":"function","title":"StepFlow.Workflows.get_processing_workflow_live/0","doc":"Returns processing live workflow with their reference and identifier","ref":"StepFlow.Workflows.html#get_processing_workflow_live/0"},{"type":"function","title":"StepFlow.Workflows.get_step_definition/1","doc":"","ref":"StepFlow.Workflows.html#get_step_definition/1"},{"type":"function","title":"StepFlow.Workflows.get_workflow!/1","doc":"Gets a single workflows.\n\nRaises `Ecto.NoResultsError` if the Workflow does not exist.","ref":"StepFlow.Workflows.html#get_workflow!/1"},{"type":"function","title":"Examples - StepFlow.Workflows.get_workflow!/1","doc":"iex> get_workflows!(123)\n    %Workflow{}\n\n    iex> get_workflows!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Workflows.html#get_workflow!/1-examples"},{"type":"function","title":"StepFlow.Workflows.get_workflow_for_job!/1","doc":"Gets a single workflows containing the specified job ID.\n\nRaises `Ecto.NoResultsError` if the Workflow does not exist.","ref":"StepFlow.Workflows.html#get_workflow_for_job!/1"},{"type":"function","title":"Examples - StepFlow.Workflows.get_workflow_for_job!/1","doc":"iex> get_workflow_for_job!(19)\n    %Workflow{}\n\n    iex> get_workflows!(456)\n    ** (Ecto.NoResultsError)","ref":"StepFlow.Workflows.html#get_workflow_for_job!/1-examples"},{"type":"function","title":"StepFlow.Workflows.get_workflow_version_as_string/1","doc":"Convert workflow version fields to a version string","ref":"StepFlow.Workflows.html#get_workflow_version_as_string/1"},{"type":"function","title":"StepFlow.Workflows.list_workflows/1","doc":"Returns the list of workflows.","ref":"StepFlow.Workflows.html#list_workflows/1"},{"type":"function","title":"Examples - StepFlow.Workflows.list_workflows/1","doc":"iex> list_workflows()\n    [%Workflow{}, ...]","ref":"StepFlow.Workflows.html#list_workflows/1-examples"},{"type":"function","title":"StepFlow.Workflows.pause/3","doc":"","ref":"StepFlow.Workflows.html#pause/3"},{"type":"function","title":"StepFlow.Workflows.preload_workflows/2","doc":"","ref":"StepFlow.Workflows.html#preload_workflows/2"},{"type":"function","title":"StepFlow.Workflows.resume/1","doc":"","ref":"StepFlow.Workflows.html#resume/1"},{"type":"function","title":"StepFlow.Workflows.update_workflow/2","doc":"Updates a workflow.","ref":"StepFlow.Workflows.html#update_workflow/2"},{"type":"function","title":"Examples - StepFlow.Workflows.update_workflow/2","doc":"iex> update_workflow(workflow, %{field: new_value})\n    {:ok, %Workflow{}}\n\n    iex> update_workflow(workflow, %{field: bad_value})\n    {:error, %Ecto.Changeset{}}","ref":"StepFlow.Workflows.html#update_workflow/2-examples"},{"type":"module","title":"StepFlow.Workflows.Status.StateEnum","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.cast/1","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#cast/1"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.dump/1","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#dump/1"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.embed_as/1","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#embed_as/1"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.equal?/2","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#equal?/2"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.load/1","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#load/1"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.type/0","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#type/0"},{"type":"function","title":"StepFlow.Workflows.Status.StateEnum.valid_value?/1","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#valid_value?/1"},{"type":"type","title":"StepFlow.Workflows.Status.StateEnum.t/0","doc":"","ref":"StepFlow.Workflows.Status.StateEnum.html#t:t/0"},{"type":"module","title":"StepFlow.Workflows.StepManager","doc":"The Step Manager context.","ref":"StepFlow.Workflows.StepManager.html"},{"type":"function","title":"StepFlow.Workflows.StepManager.check_step_progression/1","doc":"","ref":"StepFlow.Workflows.StepManager.html#check_step_progression/1"},{"type":"function","title":"StepFlow.Workflows.StepManager.check_step_status/1","doc":"","ref":"StepFlow.Workflows.StepManager.html#check_step_status/1"},{"type":"function","title":"StepFlow.Workflows.StepManager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"StepFlow.Workflows.StepManager.html#child_spec/1"},{"type":"function","title":"StepFlow.Workflows.StepManager.init/1","doc":"","ref":"StepFlow.Workflows.StepManager.html#init/1"},{"type":"function","title":"StepFlow.Workflows.StepManager.start_link/0","doc":"","ref":"StepFlow.Workflows.StepManager.html#start_link/0"},{"type":"extras","title":"Step Flow","doc":"# Step Flow\n\n[![travis-ci.org](https://travis-ci.org/media-io/ex_step_flow.svg?branch=master)](https://travis-ci.org/media-io/ex_step_flow)\n[![hex.pm](https://img.shields.io/hexpm/v/step_flow.svg)](https://hex.pm/packages/step_flow)\n[![hexdocs.pm](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/ex_step_flow/)\n[![hex.pm](https://img.shields.io/hexpm/dt/step_flow.svg)](https://hex.pm/packages/step_flow)\n[![hex.pm](https://img.shields.io/hexpm/l/step_flow.svg)](https://hex.pm/packages/step_flow)\n[![coveralls.io](https://coveralls.io/repos/github/media-io/ex_step_flow/badge.svg?branch=master)](https://coveralls.io/github/media-io/ex_step_flow?branch=master)\n\nStep flow manager for Elixir applications.","ref":"readme.html"},{"type":"extras","title":"Usage - Step Flow","doc":"Add AMQP as a dependency in your `mix.exs` file.\n\n```elixir\ndef deps do\n  [\n    {:step_flow, \"~> 0.1.0\"}\n  ]\nend\n```\n\nAnd add into extra applications:\n\n```elixir\n  def application do\n    [\n      mod: {MyApplication.Application, []},\n      extra_applications: [\n        :step_flow\n      ]\n    ]\n  end\n```","ref":"readme.html#usage"},{"type":"extras","title":"Workflows and Jobs State Machines - Step Flow","doc":"The state machines are described in dedicated pages, for\n[workflows](./docs/JOBS_STATE_MACHINE.md) and for\n[jobs](./docs/WORKFLOWS_STATE_MACHINE.md) respectively.","ref":"readme.html#workflows-and-jobs-state-machines"},{"type":"extras","title":"Configurations to start - Step Flow","doc":"","ref":"readme.html#configurations-to-start"},{"type":"extras","title":"PostgreSQL configuration - Step Flow","doc":"Add into configuration files:\n\n```elixir\nconfig :step_flow, Ecto.Repo,\n  hostname: \"localhost\",\n  username: \"postgres\",\n  password: \"postgres\",\n  database: \"step_flow_dev\",\n  runtime_pool_size: 10\n```\n\nIt can also be used with environment variables:\n\n```elixir\nconfig :step_flow, Ecto.Repo,\n  hostname: {:system, \"DATABASE_HOSTNAME\"},\n  username: {:system, \"DATABASE_USERNAME\"},\n  password: {:system, \"DATABASE_PASSWORD\"},\n  database: {:system, \"DATABASE_NAME\"},\n  runtime_pool_size: {:system, \"DATABASE_POOL_SIZE\"}\n```","ref":"readme.html#postgresql-configuration"},{"type":"extras","title":"RabbitMQ configuration - Step Flow","doc":"Add into configuration files:\n\n```elixir\nconfig :step_flow, StepFlow.Amqp,\n  hostname: \"localhost\",\n  port: 5672,\n  username: \"guest\",\n  password: \"guest\",\n  virtual_host: \"\"\n```\n\nTo set TLS over AMQP, specific configuration fields can be added:\n```elixir\nconfig :step_flow, StepFlow.Amqp,\n  hostname: \"localhost\",\n  port: 5672,\n  username: \"guest\",\n  password: \"guest\",\n  virtual_host: \"\",\n  scheme: \"amqp\",\n  ssl_cacertfile: '/path/to/ca/cacert.pem',\n  ssl_certfile: '/path/to/client/cert.pem',\n  ssl_keyfile: '/path/to/client/key.pem',\n  # only necessary with intermediate CAs\n  ssl_depth: 2,\n  ssl_verify: :verify_peer,\n  ssl_fail_if_no_peer_cert: true\n```\n\nIt can also be used with environment variables:\n\n```elixir\nconfig :step_flow, StepFlow.Amqp,\n  hostname: {:system, \"RABBITMQ_HOSTNAME\"},\n  port: {:system, \"RABBITMQ_PORT\"},\n  username: {:system, \"RABBITMQ_USERNAME\"},\n  password: {:system, \"RABBITMQ_PASSWORD\"},\n  virtual_host: {:system, \"RABBITMQ_VIRTUAL_HOST\"},\n  scheme: {:system, \"RABBITMQ_SCHEME\"},\n  ssl_cacertfile: {:system, \"RABBITMQ_SSL_CACERT_FILE\"},\n  ssl_certfile: {:system, \"RABBITMQ_SSL_CERT_FILE\"},\n  ssl_keyfile: {:system, \"RABBITMQ_SSL_KEY_FILE\"},\n  ssl_depth: {:system, \"RABBITMQ_SSL_DEPTH\"},\n  ssl_verify: {:system, \"RABBITMQ_SSL_VERIFY\"},\n  ssl_fail_if_no_peer_cert: {:system, \"RABBITMQ_SSL_FAIL_IF_NO_PEER_CERT\"},\n  server_configuration: {:system, \"RABBITMQ_SERVER_CONFIGURATION\"}\n```","ref":"readme.html#rabbitmq-configuration"},{"type":"extras","title":"Slack integration (optional) - Step Flow","doc":"Configuring the Slack integration enable notification to Slack channel.\nIt's used to:\n- send notification when job is in error\n- send a notification via a Step\n\nTo enable integration, update configuration files:\n```\nconfig :step_flow, StepFlow,\n  exposed_domain_name: {:system, \"EXPOSED_DOMAIN_NAME\"},\n  slack_api_token: {:system, \"SLACK_API_TOKEN\"},\n  slack_api_channel: {:system, \"SLACK_API_CHANNEL\"}\n```\n\nRemarks: the `slack_api_channel` configure the channel for error jobs notification.\nThe message contains also a link to the workflow, so `exposed_domain_name` configure the hostname of the hosted application.","ref":"readme.html#slack-integration-optional"},{"type":"extras","title":"Expose StepFlow REST API - Step Flow","doc":"Step Flow provides the REST API to manage Workflows and Jobs.\n\nCreate a module with:\n\n```elixir\ndefmodule MyApplicationWeb.StepFlow.Plug do\n  @moduledoc false\n\n  use StepFlow.Plug\nend\n```\n\nThen in Phoenix router redirect the API part to the module:\n\n```elixir\ndefmodule MyApplicationWeb.Router do\n  use MyApplicationWeb, :router\n\n  pipeline :api do\n    plug(:accepts, [\"json\"])\n  end\n\n  scope \"/api\", MyApplicationWeb do\n    pipe_through(:api)\n\n    scope \"/step_flow\", StepFlow do\n      forward(\"/\", Plug)\n    end\n\n    # add other routes here\n  end\nend\n\n```\n\nTo enable authentication checks over Step Flow API configure callbacks in configuration:\n\n```elixir\nconfig :step_flow, StepFlow,\n  authorize: [\n    module: MyApplicationWeb.Authorize,\n    get_jobs: [:user_check, :right_technician_check],\n    get_workflows: [:user_check, :right_technician_check],\n    post_workflows: [:user_check, :right_technician_check],\n    put_workflows: [:user_check, :right_technician_check],\n    delete_workflows: [:user_check, :right_technician_check],\n    post_workflows_events: [:user_check, :right_technician_check],\n    get_definitions: [:user_check, :right_technician_check],\n    post_worker_definitions: [:user_check, :right_technician_check],\n    get_worker_definitions: [:user_check, :right_technician_check],\n    get_workflows_statistics: [:user_check]\n  ]\n```","ref":"readme.html#expose-stepflow-rest-api"},{"type":"extras","title":"Enable StepFlow live notification to WebSocket - Step Flow","doc":"StepFlow can be configured to send messages on job updates (to enable refresh of UI via WebSocket for example).\nTo broadcast messages, the application endpoint needs to be configured.\n\n```elixir\nconfig :step_flow, StepFlow,\n  endpoint: MyApplicationWeb.Endpoint\n```","ref":"readme.html#enable-stepflow-live-notification-to-websocket"},{"type":"extras","title":"Configuration of the default working directory for workers - Step Flow","doc":"Each workers works with big data files, mostly on shared storage.\nThe default access point need to be configured using:\n\n```elixir\nconfig :step_flow, StepFlow,\n  workers_work_directory: \"/data/mount/point\"\n```","ref":"readme.html#configuration-of-the-default-working-directory-for-workers"},{"type":"extras","title":"Configuration of the default stepflow schema - Step Flow","doc":"A workflow follows a schema definition, this definition can be overloaded with:\n\n```elixir\nconfig :step_flow, StepFlow.WorkflowDefinitions.ExternalLoader, specification_folder: \"./mediacloudai/\"\n\nconfig :step_flow, StepFlow.WorkflowDefinitions.WorkflowDefinition,\n  workflow_schema_url: \"./mediacloudai/standard/1.11/workflow-definition.schema.json\"\n```","ref":"readme.html#configuration-of-the-default-stepflow-schema"},{"type":"extras","title":"Prometheus exporter - Step Flow","doc":"Several metrics are defined to monitor step flow:\n- number of workflows per identifier created in the last 24 hours\n- execution time of worflows per identifier of ended worflow in the last 24 hours\n\nMetrics can be exported by:\n\n```elixir\nconfig :step_flow, StepFlow,\n  enable_metrics: true # activate metrics\n```\n\nMetric exports can be formatted:\n\n```elixir\nconfig :prometheus, StepFlow.Metrics.PrometheusExporter,\n  format: :auto,","ref":"readme.html#prometheus-exporter"},{"type":"extras","title":"or :protobuf, or :text - Step Flow","doc":"```\n\nExport endpoint can be optionally secured using HTTP Basic Authentication:\n\n```elixir\nconfig :prometheus, StepFlow.Metrics.PrometheusExporter,\n  auth: {:basic, \"username\", \"password\"}\n```\n\nMetrics can be configured with\n\n```elixir\nconfig :step_flow, StepFlow.Metrics,\n  scale: \"day\", # \"year\", \"month\", \"week\", \"day\", \"hour\", \"minute\", \"second\", \"millisecond\", and \"microsecond\"\n  delta: -1\n```","ref":"readme.html#or-protobuf-or-text"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,50,46,50]}}